Class: Google::Apis::AdminDirectoryV1::BuildingAddress
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::BuildingAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Public API: Resources.buildings
Instance Attribute Summary collapse
-
#address_lines ⇒ Array<String>
Unstructured address lines describing the lower levels of an address.
-
#administrative_area ⇒ String
Optional.
-
#language_code ⇒ String
Optional.
-
#locality ⇒ String
Optional.
-
#postal_code ⇒ String
Optional.
-
#region_code ⇒ String
Required.
-
#sublocality ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BuildingAddress
constructor
A new instance of BuildingAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BuildingAddress
Returns a new instance of BuildingAddress.
622 623 624 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 622 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_lines ⇒ Array<String>
Unstructured address lines describing the lower levels of an address.
Corresponds to the JSON property addressLines
586 587 588 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 586 def address_lines @address_lines end |
#administrative_area ⇒ String
Optional. Highest administrative subdivision which is used for postal
addresses of a country or region.
Corresponds to the JSON property administrativeArea
592 593 594 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 592 def administrative_area @administrative_area end |
#language_code ⇒ String
Optional. BCP-47 language code of the contents of this address (if known).
Corresponds to the JSON property languageCode
597 598 599 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 597 def language_code @language_code end |
#locality ⇒ String
Optional. Generally refers to the city/town portion of the address. Examples:
US city, IT comune, UK post town. In regions of the world where localities are
not well defined or do not fit into this structure well, leave locality empty
and use addressLines.
Corresponds to the JSON property locality
605 606 607 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 605 def locality @locality end |
#postal_code ⇒ String
Optional. Postal code of the address.
Corresponds to the JSON property postalCode
610 611 612 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 610 def postal_code @postal_code end |
#region_code ⇒ String
Required. CLDR region code of the country/region of the address.
Corresponds to the JSON property regionCode
615 616 617 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 615 def region_code @region_code end |
#sublocality ⇒ String
Optional. Sublocality of the address.
Corresponds to the JSON property sublocality
620 621 622 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 620 def sublocality @sublocality end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
627 628 629 630 631 632 633 634 635 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 627 def update!(**args) @address_lines = args[:address_lines] if args.key?(:address_lines) @administrative_area = args[:administrative_area] if args.key?(:administrative_area) @language_code = args[:language_code] if args.key?(:language_code) @locality = args[:locality] if args.key?(:locality) @postal_code = args[:postal_code] if args.key?(:postal_code) @region_code = args[:region_code] if args.key?(:region_code) @sublocality = args[:sublocality] if args.key?(:sublocality) end |