Class: Google::Apis::AdminDirectoryV1::Buildings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Public API: Resources.buildings

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Buildings

Returns a new instance of Buildings.



688
689
690
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buildingsArray<Google::Apis::AdminDirectoryV1::Building>

The Buildings in this page of results. Corresponds to the JSON property buildings



670
671
672
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 670

def buildings
  @buildings
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


675
676
677
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 675

def etag
  @etag
end

#kindString

Kind of resource this is. Corresponds to the JSON property kind

Returns:

  • (String)


680
681
682
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 680

def kind
  @kind
end

#next_page_tokenString

The continuation token, used to page through large result sets. Provide this value in a subsequent request to return the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


686
687
688
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 686

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



693
694
695
696
697
698
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 693

def update!(**args)
  @buildings = args[:buildings] if args.key?(:buildings)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end