Class: Google::Apis::AdminDirectoryV1::CalendarResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Public API: Resources.calendars

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarResource

Returns a new instance of CalendarResource.



810
811
812
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#building_idString

Unique ID for the building a resource is located in. Corresponds to the JSON property buildingId

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 733

def building_id
  @building_id
end

#capacityFixnum

Capacity of a resource, number of seats in a room. Corresponds to the JSON property capacity

Returns:

  • (Fixnum)


738
739
740
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 738

def capacity
  @capacity
end

#etagsString

ETag of the resource. Corresponds to the JSON property etags

Returns:

  • (String)


743
744
745
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 743

def etags
  @etags
end

#feature_instancesObject

Instances of features for the calendar resource. Corresponds to the JSON property featureInstances

Returns:

  • (Object)


748
749
750
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 748

def feature_instances
  @feature_instances
end

#floor_nameString

Name of the floor a resource is located on. Corresponds to the JSON property floorName

Returns:

  • (String)


753
754
755
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 753

def floor_name
  @floor_name
end

#floor_sectionString

Name of the section within a floor a resource is located in. Corresponds to the JSON property floorSection

Returns:

  • (String)


758
759
760
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 758

def floor_section
  @floor_section
end

#generated_resource_nameString

The read-only auto-generated name of the calendar resource which includes metadata about the resource such as building name, floor, capacity, etc. For example, "NYC-2-Training Room 1A (16)". Corresponds to the JSON property generatedResourceName

Returns:

  • (String)


765
766
767
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 765

def generated_resource_name
  @generated_resource_name
end

#kindString

The type of the resource. For calendar resources, the value is admin# directory#resources#calendars#CalendarResource. Corresponds to the JSON property kind

Returns:

  • (String)


771
772
773
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 771

def kind
  @kind
end

#resource_categoryString

The category of the calendar resource. Either CONFERENCE_ROOM or OTHER. Legacy data is set to CATEGORY_UNKNOWN. Corresponds to the JSON property resourceCategory

Returns:

  • (String)


777
778
779
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 777

def resource_category
  @resource_category
end

#resource_descriptionString

Description of the resource, visible only to admins. Corresponds to the JSON property resourceDescription

Returns:

  • (String)


782
783
784
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 782

def resource_description
  @resource_description
end

#resource_emailString

The read-only email for the calendar resource. Generated as part of creating a new calendar resource. Corresponds to the JSON property resourceEmail

Returns:

  • (String)


788
789
790
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 788

def resource_email
  @resource_email
end

#resource_idString

The unique ID for the calendar resource. Corresponds to the JSON property resourceId

Returns:

  • (String)


793
794
795
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 793

def resource_id
  @resource_id
end

#resource_nameString

The name of the calendar resource. For example, "Training Room 1A". Corresponds to the JSON property resourceName

Returns:

  • (String)


798
799
800
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 798

def resource_name
  @resource_name
end

#resource_typeString

The type of the calendar resource, intended for non-room resources. Corresponds to the JSON property resourceType

Returns:

  • (String)


803
804
805
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 803

def resource_type
  @resource_type
end

#user_visible_descriptionString

Description of the resource, visible to users and admins. Corresponds to the JSON property userVisibleDescription

Returns:

  • (String)


808
809
810
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 808

def user_visible_description
  @user_visible_description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 815

def update!(**args)
  @building_id = args[:building_id] if args.key?(:building_id)
  @capacity = args[:capacity] if args.key?(:capacity)
  @etags = args[:etags] if args.key?(:etags)
  @feature_instances = args[:feature_instances] if args.key?(:feature_instances)
  @floor_name = args[:floor_name] if args.key?(:floor_name)
  @floor_section = args[:floor_section] if args.key?(:floor_section)
  @generated_resource_name = args[:generated_resource_name] if args.key?(:generated_resource_name)
  @kind = args[:kind] if args.key?(:kind)
  @resource_category = args[:resource_category] if args.key?(:resource_category)
  @resource_description = args[:resource_description] if args.key?(:resource_description)
  @resource_email = args[:resource_email] if args.key?(:resource_email)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @resource_name = args[:resource_name] if args.key?(:resource_name)
  @resource_type = args[:resource_type] if args.key?(:resource_type)
  @user_visible_description = args[:user_visible_description] if args.key?(:user_visible_description)
end