Class: Google::Apis::AdminDirectoryV1::ChromeOsDevices
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::ChromeOsDevices
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Instance Attribute Summary collapse
-
#chromeosdevices ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice>
A list of Chrome OS Device objects.
-
#etag ⇒ String
ETag of the resource.
-
#kind ⇒ String
Kind of resource this is.
-
#next_page_token ⇒ String
Token used to access the next page of this result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChromeOsDevices
constructor
A new instance of ChromeOsDevices.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChromeOsDevices
Returns a new instance of ChromeOsDevices.
1883 1884 1885 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1883 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chromeosdevices ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice>
A list of Chrome OS Device objects.
Corresponds to the JSON property chromeosdevices
1865 1866 1867 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1865 def chromeosdevices @chromeosdevices end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
1870 1871 1872 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1870 def etag @etag end |
#kind ⇒ String
Kind of resource this is.
Corresponds to the JSON property kind
1875 1876 1877 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1875 def kind @kind end |
#next_page_token ⇒ String
Token used to access the next page of this result. To access the next page,
use this token's value in the pageToken query string of this request.
Corresponds to the JSON property nextPageToken
1881 1882 1883 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1881 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1888 1889 1890 1891 1892 1893 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1888 def update!(**args) @chromeosdevices = args[:chromeosdevices] if args.key?(:chromeosdevices) @etag = args[:etag] if args.key?(:etag) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |