Class: Google::Apis::AdminDirectoryV1::Customer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Customer

Returns a new instance of Customer.



2042
2043
2044
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternate_emailString

The customer's secondary contact email address. This email address cannot be on the same domain as the customerDomain Corresponds to the JSON property alternateEmail

Returns:

  • (String)


1994
1995
1996
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1994

def alternate_email
  @alternate_email
end

#customer_creation_timeDateTime

The customer's creation time (Readonly) Corresponds to the JSON property customerCreationTime

Returns:

  • (DateTime)


1999
2000
2001
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1999

def customer_creation_time
  @customer_creation_time
end

#customer_domainString

The customer's primary domain name string. Do not include the www prefix when creating a new customer. Corresponds to the JSON property customerDomain

Returns:

  • (String)


2005
2006
2007
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2005

def customer_domain
  @customer_domain
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


2010
2011
2012
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2010

def etag
  @etag
end

#idString

The unique ID for the customer's Google Workspace account. (Readonly) Corresponds to the JSON property id

Returns:

  • (String)


2015
2016
2017
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2015

def id
  @id
end

#kindString

Identifies the resource as a customer. Value: admin#directory#customer Corresponds to the JSON property kind

Returns:

  • (String)


2020
2021
2022
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2020

def kind
  @kind
end

#languageString

The customer's ISO 639-2 language code. See the Language Codes page for the list of supported codes. Valid language codes outside the supported set will be accepted by the API but may lead to unexpected behavior. The default value is en. Corresponds to the JSON property language

Returns:

  • (String)


2029
2030
2031
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2029

def language
  @language
end

#phone_numberString

The customer's contact phone number in E.164 format. Corresponds to the JSON property phoneNumber

Returns:

  • (String)


2035
2036
2037
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2035

def phone_number
  @phone_number
end

#postal_addressGoogle::Apis::AdminDirectoryV1::CustomerPostalAddress

The customer's postal address information. Corresponds to the JSON property postalAddress



2040
2041
2042
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2040

def postal_address
  @postal_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2047
2048
2049
2050
2051
2052
2053
2054
2055
2056
2057
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2047

def update!(**args)
  @alternate_email = args[:alternate_email] if args.key?(:alternate_email)
  @customer_creation_time = args[:customer_creation_time] if args.key?(:customer_creation_time)
  @customer_domain = args[:customer_domain] if args.key?(:customer_domain)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @language = args[:language] if args.key?(:language)
  @phone_number = args[:phone_number] if args.key?(:phone_number)
  @postal_address = args[:postal_address] if args.key?(:postal_address)
end