Class: Google::Apis::AdminDirectoryV1::CustomerPostalAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomerPostalAddress

Returns a new instance of CustomerPostalAddress.



2115
2116
2117
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#address_line1String

A customer's physical address. The address can be composed of one to three lines. Corresponds to the JSON property addressLine1

Returns:

  • (String)


2068
2069
2070
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2068

def address_line1
  @address_line1
end

#address_line2String

Address line 2 of the address. Corresponds to the JSON property addressLine2

Returns:

  • (String)


2073
2074
2075
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2073

def address_line2
  @address_line2
end

#address_line3String

Address line 3 of the address. Corresponds to the JSON property addressLine3

Returns:

  • (String)


2078
2079
2080
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2078

def address_line3
  @address_line3
end

#contact_nameString

The customer contact's name. Corresponds to the JSON property contactName

Returns:

  • (String)


2083
2084
2085
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2083

def contact_name
  @contact_name
end

#country_codeString

This is a required property. For countryCode information see the ISO 3166 country code elements. Corresponds to the JSON property countryCode

Returns:

  • (String)


2089
2090
2091
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2089

def country_code
  @country_code
end

#localityString

Name of the locality. An example of a locality value is the city of San Francisco. Corresponds to the JSON property locality

Returns:

  • (String)


2095
2096
2097
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2095

def locality
  @locality
end

#organization_nameString

The company or company division name. Corresponds to the JSON property organizationName

Returns:

  • (String)


2100
2101
2102
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2100

def organization_name
  @organization_name
end

#postal_codeString

The postal code. A postalCode example is a postal zip code such as 10009. This is in accordance with - http: //portablecontacts.net/draft-spec.html# address_element. Corresponds to the JSON property postalCode

Returns:

  • (String)


2107
2108
2109
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2107

def postal_code
  @postal_code
end

#regionString

Name of the region. An example of a region value is NY for the state of New York. Corresponds to the JSON property region

Returns:

  • (String)


2113
2114
2115
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2113

def region
  @region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2120
2121
2122
2123
2124
2125
2126
2127
2128
2129
2130
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2120

def update!(**args)
  @address_line1 = args[:address_line1] if args.key?(:address_line1)
  @address_line2 = args[:address_line2] if args.key?(:address_line2)
  @address_line3 = args[:address_line3] if args.key?(:address_line3)
  @contact_name = args[:contact_name] if args.key?(:contact_name)
  @country_code = args[:country_code] if args.key?(:country_code)
  @locality = args[:locality] if args.key?(:locality)
  @organization_name = args[:organization_name] if args.key?(:organization_name)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @region = args[:region] if args.key?(:region)
end