Class: Google::Apis::AdminDirectoryV1::DirectoryChromeosdevicesCommand

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Information regarding a command that was issued to a device.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DirectoryChromeosdevicesCommand

Returns a new instance of DirectoryChromeosdevicesCommand.



2173
2174
2175
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#command_expire_timeString

The time at which the command will expire. If the device doesn't execute the command within this time the command will become expired. Corresponds to the JSON property commandExpireTime

Returns:

  • (String)


2141
2142
2143
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2141

def command_expire_time
  @command_expire_time
end

#command_idFixnum

Unique ID of a device command. Corresponds to the JSON property commandId

Returns:

  • (Fixnum)


2146
2147
2148
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2146

def command_id
  @command_id
end

#command_resultGoogle::Apis::AdminDirectoryV1::DirectoryChromeosdevicesCommandResult

The result of executing a command. Corresponds to the JSON property commandResult



2151
2152
2153
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2151

def command_result
  @command_result
end

#issue_timeString

The timestamp when the command was issued by the admin. Corresponds to the JSON property issueTime

Returns:

  • (String)


2156
2157
2158
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2156

def issue_time
  @issue_time
end

#payloadString

The payload that the command specified, if any. Corresponds to the JSON property payload

Returns:

  • (String)


2161
2162
2163
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2161

def payload
  @payload
end

#stateString

Indicates the command state. Corresponds to the JSON property state

Returns:

  • (String)


2166
2167
2168
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2166

def state
  @state
end

#typeString

The type of the command. Corresponds to the JSON property type

Returns:

  • (String)


2171
2172
2173
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2171

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2178
2179
2180
2181
2182
2183
2184
2185
2186
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2178

def update!(**args)
  @command_expire_time = args[:command_expire_time] if args.key?(:command_expire_time)
  @command_id = args[:command_id] if args.key?(:command_id)
  @command_result = args[:command_result] if args.key?(:command_result)
  @issue_time = args[:issue_time] if args.key?(:issue_time)
  @payload = args[:payload] if args.key?(:payload)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
end