Class: Google::Apis::AdminDirectoryV1::DirectoryChromeosdevicesIssueCommandRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

A request for issuing a command.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DirectoryChromeosdevicesIssueCommandRequest

Returns a new instance of DirectoryChromeosdevicesIssueCommandRequest.



2284
2285
2286
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#command_typeString

The type of command. Corresponds to the JSON property commandType

Returns:

  • (String)


2244
2245
2246
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2244

def command_type
  @command_type
end

#payloadString

The payload for the command, provide it only if command supports it. The following commands support adding payload: * SET_VOLUME: Payload is a stringified JSON object in the form: "volume": 50. The volume has to be an integer in the range [0,100]. * DEVICE_START_CRD_SESSION: Payload is optionally a stringified JSON object in the form: "ackedUserPresence": true, "crdSessionType": string. ackedUserPresence is a boolean. By default, ackedUserPresence is set to false. To start a Chrome Remote Desktop session for an active device, set ackedUserPresence to true. crdSessionType can only select from values private (which grants the remote admin exclusive control of the ChromeOS device) or shared (which allows the admin and the local user to share control of the ChromeOS device). If not set, crdSessionType defaults to shared. The FETCH_CRD_AVAILABILITY_INFO command can be used to determine available session types on the device. * REBOOT: Payload is a stringified JSON object in the form: " user_session_delay_seconds": 300. The user_session_delay_seconds is the amount of seconds to wait before rebooting the device if a user is logged in. It has to be an integer in the range [0,300]. When payload is not present for reboot, 0 delay is the default. Note: This only applies if an actual user is logged in, including a Guest. If the device is in the login screen or in Kiosk mode the value is not respected and the device immediately reboots. * FETCH_SUPPORT_PACKET: Payload is optionally a stringified JSON object in the form: "supportPacketDetails": "issueCaseId": optional_support_case_id_string, "issueDescription": optional_issue_description_string, " requestedDataCollectors": []`The list of availabledata_collector_enums are as following: Chrome System Information (1), Crash IDs (2), Memory Details (3), UI Hierarchy (4), Additional ChromeOS Platform Logs (5), Device Event (6), Intel WiFi NICs Debug Dump (7), Touch Events (8), Lacros (9), Lacros System Information (10), ChromeOS Flex Logs (11), DBus Details (12), ChromeOS Network Routes (13), ChromeOS Shill (Connection Manager) Logs (14), Policies (15), ChromeOS System State and Logs (16), ChromeOS System Logs (17), ChromeOS Chrome User Logs (18), ChromeOS Bluetooth (19), ChromeOS Connected Input Devices (20), ChromeOS Traffic Counters (21), ChromeOS Virtual Keyboard (22), ChromeOS Network Health (23). See more details in [help article](https:// support.google.com/chrome/a?p=remote-log). Corresponds to the JSON propertypayload`

Returns:

  • (String)


2282
2283
2284
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2282

def payload
  @payload
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2289
2290
2291
2292
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2289

def update!(**args)
  @command_type = args[:command_type] if args.key?(:command_type)
  @payload = args[:payload] if args.key?(:payload)
end