Class: Google::Apis::AdminDirectoryV1::DomainAlias
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::DomainAlias
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Instance Attribute Summary collapse
-
#creation_time ⇒ Fixnum
The creation time of the domain alias.
-
#domain_alias_name ⇒ String
The domain alias name.
-
#etag ⇒ String
ETag of the resource.
-
#kind ⇒ String
Kind of resource this is.
-
#parent_domain_name ⇒ String
The parent domain name that the domain alias is associated with.
-
#verified ⇒ Boolean
(also: #verified?)
Indicates the verification state of a domain alias.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DomainAlias
constructor
A new instance of DomainAlias.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DomainAlias
Returns a new instance of DomainAlias.
2377 2378 2379 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_time ⇒ Fixnum
The creation time of the domain alias. (Read-only).
Corresponds to the JSON property creationTime
2348 2349 2350 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2348 def creation_time @creation_time end |
#domain_alias_name ⇒ String
The domain alias name.
Corresponds to the JSON property domainAliasName
2353 2354 2355 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2353 def domain_alias_name @domain_alias_name end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
2358 2359 2360 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2358 def etag @etag end |
#kind ⇒ String
Kind of resource this is.
Corresponds to the JSON property kind
2363 2364 2365 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2363 def kind @kind end |
#parent_domain_name ⇒ String
The parent domain name that the domain alias is associated with. This can
either be a primary or secondary domain name within a customer.
Corresponds to the JSON property parentDomainName
2369 2370 2371 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2369 def parent_domain_name @parent_domain_name end |
#verified ⇒ Boolean Also known as: verified?
Indicates the verification state of a domain alias. (Read-only)
Corresponds to the JSON property verified
2374 2375 2376 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2374 def verified @verified end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2382 2383 2384 2385 2386 2387 2388 2389 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2382 def update!(**args) @creation_time = args[:creation_time] if args.key?(:creation_time) @domain_alias_name = args[:domain_alias_name] if args.key?(:domain_alias_name) @etag = args[:etag] if args.key?(:etag) @kind = args[:kind] if args.key?(:kind) @parent_domain_name = args[:parent_domain_name] if args.key?(:parent_domain_name) @verified = args[:verified] if args.key?(:verified) end |