Class: Google::Apis::AdminDirectoryV1::Domains
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::Domains
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Instance Attribute Summary collapse
-
#creation_time ⇒ Fixnum
Creation time of the domain.
-
#domain_aliases ⇒ Array<Google::Apis::AdminDirectoryV1::DomainAlias>
A list of domain alias objects.
-
#domain_name ⇒ String
The domain name of the customer.
-
#etag ⇒ String
ETag of the resource.
-
#is_primary ⇒ Boolean
(also: #is_primary?)
Indicates if the domain is a primary domain (Read-only).
-
#kind ⇒ String
Kind of resource this is.
-
#verified ⇒ Boolean
(also: #verified?)
Indicates the verification state of a domain.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Domains
constructor
A new instance of Domains.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Domains
Returns a new instance of Domains.
2463 2464 2465 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_time ⇒ Fixnum
Creation time of the domain. Expressed in Unix time format. (Read-only).
Corresponds to the JSON property creationTime
2429 2430 2431 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2429 def creation_time @creation_time end |
#domain_aliases ⇒ Array<Google::Apis::AdminDirectoryV1::DomainAlias>
A list of domain alias objects. (Read-only)
Corresponds to the JSON property domainAliases
2434 2435 2436 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2434 def domain_aliases @domain_aliases end |
#domain_name ⇒ String
The domain name of the customer.
Corresponds to the JSON property domainName
2439 2440 2441 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2439 def domain_name @domain_name end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
2444 2445 2446 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2444 def etag @etag end |
#is_primary ⇒ Boolean Also known as: is_primary?
Indicates if the domain is a primary domain (Read-only).
Corresponds to the JSON property isPrimary
2449 2450 2451 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2449 def is_primary @is_primary end |
#kind ⇒ String
Kind of resource this is.
Corresponds to the JSON property kind
2455 2456 2457 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2455 def kind @kind end |
#verified ⇒ Boolean Also known as: verified?
Indicates the verification state of a domain. (Read-only).
Corresponds to the JSON property verified
2460 2461 2462 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2460 def verified @verified end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2468 2469 2470 2471 2472 2473 2474 2475 2476 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2468 def update!(**args) @creation_time = args[:creation_time] if args.key?(:creation_time) @domain_aliases = args[:domain_aliases] if args.key?(:domain_aliases) @domain_name = args[:domain_name] if args.key?(:domain_name) @etag = args[:etag] if args.key?(:etag) @is_primary = args[:is_primary] if args.key?(:is_primary) @kind = args[:kind] if args.key?(:kind) @verified = args[:verified] if args.key?(:verified) end |