Class: Google::Apis::AdminDirectoryV1::Member

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

A Google Groups member can be a user or another group. This member can be inside or outside of your account's domains. For more information about common group member tasks, see the Developer's Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Member

Returns a new instance of Member.



3062
3063
3064
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delivery_settingsString

Defines mail delivery preferences of member. This field is only supported by insert, update, and get methods. Corresponds to the JSON property delivery_settings

Returns:

  • (String)


3017
3018
3019
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3017

def delivery_settings
  @delivery_settings
end

#emailString

The member's email address. A member can be a user or another group. This property is required when adding a member to a group. The email must be unique and cannot be an alias of another group. If the email address is changed, the API automatically reflects the email address changes. Corresponds to the JSON property email

Returns:

  • (String)


3025
3026
3027
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3025

def email
  @email
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


3030
3031
3032
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3030

def etag
  @etag
end

#idString

The unique ID of the group member. A member id can be used as a member request URI's memberKey. Corresponds to the JSON property id

Returns:

  • (String)


3036
3037
3038
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3036

def id
  @id
end

#kindString

The type of the API resource. For Members resources, the value is admin# directory#member. Corresponds to the JSON property kind

Returns:

  • (String)


3042
3043
3044
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3042

def kind
  @kind
end

#roleString

The member's role in a group. The API returns an error for cycles in group memberships. For example, if group1 is a member of group2, group2 cannot be a member of group1. For more information about a member's role, see the administration help center. Corresponds to the JSON property role

Returns:

  • (String)


3050
3051
3052
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3050

def role
  @role
end

#statusString

Status of member (Immutable) Corresponds to the JSON property status

Returns:

  • (String)


3055
3056
3057
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3055

def status
  @status
end

#typeString

The type of group member. Corresponds to the JSON property type

Returns:

  • (String)


3060
3061
3062
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3060

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3067
3068
3069
3070
3071
3072
3073
3074
3075
3076
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3067

def update!(**args)
  @delivery_settings = args[:delivery_settings] if args.key?(:delivery_settings)
  @email = args[:email] if args.key?(:email)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @role = args[:role] if args.key?(:role)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end