Class: Google::Apis::AdminDirectoryV1::PrintServerFailureInfo
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::PrintServerFailureInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Info about failures
Instance Attribute Summary collapse
-
#error_code ⇒ String
Canonical code for why the update failed to apply.
-
#error_message ⇒ String
Failure reason message.
-
#print_server ⇒ Google::Apis::AdminDirectoryV1::PrintServer
Configuration for a print server.
-
#print_server_id ⇒ String
ID of a failed print server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrintServerFailureInfo
constructor
A new instance of PrintServerFailureInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrintServerFailureInfo
Returns a new instance of PrintServerFailureInfo.
3794 3795 3796 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3794 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ String
Canonical code for why the update failed to apply.
Corresponds to the JSON property errorCode
3777 3778 3779 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3777 def error_code @error_code end |
#error_message ⇒ String
Failure reason message.
Corresponds to the JSON property errorMessage
3782 3783 3784 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3782 def @error_message end |
#print_server ⇒ Google::Apis::AdminDirectoryV1::PrintServer
Configuration for a print server.
Corresponds to the JSON property printServer
3787 3788 3789 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3787 def print_server @print_server end |
#print_server_id ⇒ String
ID of a failed print server.
Corresponds to the JSON property printServerId
3792 3793 3794 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3792 def print_server_id @print_server_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3799 3800 3801 3802 3803 3804 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3799 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @print_server = args[:print_server] if args.key?(:print_server) @print_server_id = args[:print_server_id] if args.key?(:print_server_id) end |