Class: Google::Apis::AdminDirectoryV1::Printer
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::Printer
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Printer configuration.
Instance Attribute Summary collapse
-
#auxiliary_messages ⇒ Array<Google::Apis::AdminDirectoryV1::AuxiliaryMessage>
Output only.
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Editable.
-
#display_name ⇒ String
Editable.
-
#id ⇒ String
Id of the printer.
-
#make_and_model ⇒ String
Editable.
-
#name ⇒ String
Identifier.
-
#org_unit_id ⇒ String
Organization Unit that owns this printer (Only can be set during Printer creation) Corresponds to the JSON property
orgUnitId. -
#uri ⇒ String
Editable.
-
#use_driverless_config ⇒ Boolean
(also: #use_driverless_config?)
Editable.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Printer
constructor
A new instance of Printer.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Printer
Returns a new instance of Printer.
3867 3868 3869 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auxiliary_messages ⇒ Array<Google::Apis::AdminDirectoryV1::AuxiliaryMessage>
Output only. Auxiliary messages about issues with the printer configuration if
any.
Corresponds to the JSON property auxiliaryMessages
3815 3816 3817 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3815 def @auxiliary_messages end |
#create_time ⇒ String
Output only. Time when printer was created.
Corresponds to the JSON property createTime
3820 3821 3822 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3820 def create_time @create_time end |
#description ⇒ String
Editable. Description of printer.
Corresponds to the JSON property description
3825 3826 3827 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3825 def description @description end |
#display_name ⇒ String
Editable. Name of printer.
Corresponds to the JSON property displayName
3830 3831 3832 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3830 def display_name @display_name end |
#id ⇒ String
Id of the printer. (During printer creation leave empty)
Corresponds to the JSON property id
3835 3836 3837 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3835 def id @id end |
#make_and_model ⇒ String
Editable. Make and model of printer. e.g. Lexmark MS610de Value must be in
format as seen in ListPrinterModels response.
Corresponds to the JSON property makeAndModel
3841 3842 3843 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3841 def make_and_model @make_and_model end |
#name ⇒ String
Identifier. The resource name of the Printer object, in the format customers/
customer-id/printers/printer-id (During printer creation leave empty)
Corresponds to the JSON property name
3847 3848 3849 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3847 def name @name end |
#org_unit_id ⇒ String
Organization Unit that owns this printer (Only can be set during Printer
creation)
Corresponds to the JSON property orgUnitId
3853 3854 3855 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3853 def org_unit_id @org_unit_id end |
#uri ⇒ String
Editable. Printer URI.
Corresponds to the JSON property uri
3858 3859 3860 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3858 def uri @uri end |
#use_driverless_config ⇒ Boolean Also known as: use_driverless_config?
Editable. flag to use driverless configuration or not. If it's set to be true,
make_and_model can be ignored
Corresponds to the JSON property useDriverlessConfig
3864 3865 3866 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3864 def use_driverless_config @use_driverless_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3872 3873 3874 3875 3876 3877 3878 3879 3880 3881 3882 3883 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3872 def update!(**args) @auxiliary_messages = args[:auxiliary_messages] if args.key?(:auxiliary_messages) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @id = args[:id] if args.key?(:id) @make_and_model = args[:make_and_model] if args.key?(:make_and_model) @name = args[:name] if args.key?(:name) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @uri = args[:uri] if args.key?(:uri) @use_driverless_config = args[:use_driverless_config] if args.key?(:use_driverless_config) end |