Class: Google::Apis::AdminDirectoryV1::Privilege

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Privilege

Returns a new instance of Privilege.



3926
3927
3928
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#child_privilegesArray<Google::Apis::AdminDirectoryV1::Privilege>

A list of child privileges. Privileges for a service form a tree. Each privilege can have a list of child privileges; this list is empty for a leaf privilege. Corresponds to the JSON property childPrivileges



3891
3892
3893
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3891

def child_privileges
  @child_privileges
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


3896
3897
3898
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3896

def etag
  @etag
end

#is_ou_scopableBoolean Also known as: is_ou_scopable?

If the privilege can be restricted to an organization unit. Corresponds to the JSON property isOuScopable

Returns:

  • (Boolean)


3901
3902
3903
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3901

def is_ou_scopable
  @is_ou_scopable
end

#kindString

The type of the API resource. This is always admin#directory#privilege. Corresponds to the JSON property kind

Returns:

  • (String)


3907
3908
3909
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3907

def kind
  @kind
end

#privilege_nameString

The name of the privilege. Corresponds to the JSON property privilegeName

Returns:

  • (String)


3912
3913
3914
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3912

def privilege_name
  @privilege_name
end

#service_idString

The obfuscated ID of the service this privilege is for. This value is returned with Privileges.list(). Corresponds to the JSON property serviceId

Returns:

  • (String)


3919
3920
3921
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3919

def service_id
  @service_id
end

#service_nameString

The name of the service this privilege is for. Corresponds to the JSON property serviceName

Returns:

  • (String)


3924
3925
3926
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3924

def service_name
  @service_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3931
3932
3933
3934
3935
3936
3937
3938
3939
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3931

def update!(**args)
  @child_privileges = args[:child_privileges] if args.key?(:child_privileges)
  @etag = args[:etag] if args.key?(:etag)
  @is_ou_scopable = args[:is_ou_scopable] if args.key?(:is_ou_scopable)
  @kind = args[:kind] if args.key?(:kind)
  @privilege_name = args[:privilege_name] if args.key?(:privilege_name)
  @service_id = args[:service_id] if args.key?(:service_id)
  @service_name = args[:service_name] if args.key?(:service_name)
end