Class: Google::Apis::AdminDirectoryV1::Role

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Defined Under Namespace

Classes: RolePrivilege

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Role

Returns a new instance of Role.



4055
4056
4057
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


4016
4017
4018
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4016

def etag
  @etag
end

#is_super_admin_roleBoolean Also known as: is_super_admin_role?

Returns true if the role is a super admin role. Corresponds to the JSON property isSuperAdminRole

Returns:

  • (Boolean)


4021
4022
4023
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4021

def is_super_admin_role
  @is_super_admin_role
end

#is_system_roleBoolean Also known as: is_system_role?

Returns true if this is a pre-defined system role. Corresponds to the JSON property isSystemRole

Returns:

  • (Boolean)


4027
4028
4029
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4027

def is_system_role
  @is_system_role
end

#kindString

The type of the API resource. This is always admin#directory#role. Corresponds to the JSON property kind

Returns:

  • (String)


4033
4034
4035
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4033

def kind
  @kind
end

#role_descriptionString

A short description of the role. Corresponds to the JSON property roleDescription

Returns:

  • (String)


4038
4039
4040
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4038

def role_description
  @role_description
end

#role_idFixnum

ID of the role. Corresponds to the JSON property roleId

Returns:

  • (Fixnum)


4043
4044
4045
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4043

def role_id
  @role_id
end

#role_nameString

Name of the role. Corresponds to the JSON property roleName

Returns:

  • (String)


4048
4049
4050
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4048

def role_name
  @role_name
end

#role_privilegesArray<Google::Apis::AdminDirectoryV1::Role::RolePrivilege>

The set of privileges that are granted to this role. Corresponds to the JSON property rolePrivileges



4053
4054
4055
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4053

def role_privileges
  @role_privileges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4060
4061
4062
4063
4064
4065
4066
4067
4068
4069
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4060

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @is_super_admin_role = args[:is_super_admin_role] if args.key?(:is_super_admin_role)
  @is_system_role = args[:is_system_role] if args.key?(:is_system_role)
  @kind = args[:kind] if args.key?(:kind)
  @role_description = args[:role_description] if args.key?(:role_description)
  @role_id = args[:role_id] if args.key?(:role_id)
  @role_name = args[:role_name] if args.key?(:role_name)
  @role_privileges = args[:role_privileges] if args.key?(:role_privileges)
end