Class: Google::Apis::AdminDirectoryV1::SchemaFieldSpec::NumericIndexingSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Indexing spec for a numeric field. By default, only exact match queries will be supported for numeric fields. Setting the numericIndexingSpec allows range queries to be supported.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NumericIndexingSpec

Returns a new instance of NumericIndexingSpec.



4423
4424
4425
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_valueFloat

Maximum value of this field. This is meant to be indicative rather than enforced. Values outside this range will still be indexed, but search may not be as performant. Corresponds to the JSON property maxValue

Returns:

  • (Float)


4414
4415
4416
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4414

def max_value
  @max_value
end

#min_valueFloat

Minimum value of this field. This is meant to be indicative rather than enforced. Values outside this range will still be indexed, but search may not be as performant. Corresponds to the JSON property minValue

Returns:

  • (Float)


4421
4422
4423
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4421

def min_value
  @min_value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4428
4429
4430
4431
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4428

def update!(**args)
  @max_value = args[:max_value] if args.key?(:max_value)
  @min_value = args[:min_value] if args.key?(:min_value)
end