Class: Google::Apis::AdminDirectoryV1::UserAbout
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserAbout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
JSON template for About (notes) of a user in Directory API.
Instance Attribute Summary collapse
-
#content_type ⇒ String
About entry can have a type which indicates the content type.
-
#value ⇒ String
Actual value of notes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserAbout
constructor
A new instance of UserAbout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserAbout
Returns a new instance of UserAbout.
5006 5007 5008 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
About entry can have a type which indicates the content type. It can either be
plain or html. By default, notes contents are assumed to contain plain text.
Corresponds to the JSON property contentType
4999 5000 5001 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4999 def content_type @content_type end |
#value ⇒ String
Actual value of notes.
Corresponds to the JSON property value
5004 5005 5006 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5004 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5011 5012 5013 5014 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5011 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @value = args[:value] if args.key?(:value) end |