Class: Google::Apis::AdminDirectoryV1::UserEmail
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserEmail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
JSON template for an email.
Defined Under Namespace
Classes: PublicKeyEncryptionCertificates
Instance Attribute Summary collapse
-
#address ⇒ String
Email id of the user.
-
#custom_type ⇒ String
Custom Type.
-
#primary ⇒ Boolean
(also: #primary?)
If this is user's primary email.
-
#public_key_encryption_certificates ⇒ Google::Apis::AdminDirectoryV1::UserEmail::PublicKeyEncryptionCertificates
Public Key Encryption Certificates.
-
#type ⇒ String
Each entry can have a type which indicates standard types of that entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserEmail
constructor
A new instance of UserEmail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserEmail
Returns a new instance of UserEmail.
5159 5160 5161 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Email id of the user.
Corresponds to the JSON property address
5132 5133 5134 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5132 def address @address end |
#custom_type ⇒ String
Custom Type.
Corresponds to the JSON property customType
5137 5138 5139 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5137 def custom_type @custom_type end |
#primary ⇒ Boolean Also known as: primary?
If this is user's primary email. Only one entry could be marked as primary.
Corresponds to the JSON property primary
5142 5143 5144 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5142 def primary @primary end |
#public_key_encryption_certificates ⇒ Google::Apis::AdminDirectoryV1::UserEmail::PublicKeyEncryptionCertificates
Public Key Encryption Certificates. Current limit: 1 per email address, and 5
per user.
Corresponds to the JSON property public_key_encryption_certificates
5149 5150 5151 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5149 def public_key_encryption_certificates @public_key_encryption_certificates end |
#type ⇒ String
Each entry can have a type which indicates standard types of that entry. For
example email could be of home, work etc. In addition to the standard type, an
entry can have a custom type and can take any value Such types should have the
CUSTOM value as type and also have a customType value.
Corresponds to the JSON property type
5157 5158 5159 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5157 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5164 5165 5166 5167 5168 5169 5170 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5164 def update!(**args) @address = args[:address] if args.key?(:address) @custom_type = args[:custom_type] if args.key?(:custom_type) @primary = args[:primary] if args.key?(:primary) @public_key_encryption_certificates = args[:public_key_encryption_certificates] if args.key?(:public_key_encryption_certificates) @type = args[:type] if args.key?(:type) end |