Class: Google::Apis::AdminDirectoryV1::UserEmail::PublicKeyEncryptionCertificates
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserEmail::PublicKeyEncryptionCertificates
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Public Key Encryption Certificates. Current limit: 1 per email address, and 5 per user.
Instance Attribute Summary collapse
-
#certificate ⇒ String
X.509 encryption certificate in
PEMformat. -
#is_default ⇒ Boolean
(also: #is_default?)
Whether this is the default certificate for the given email address.
-
#state ⇒ String
Denotes the certificate's state in its lifecycle.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicKeyEncryptionCertificates
constructor
A new instance of PublicKeyEncryptionCertificates.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicKeyEncryptionCertificates
Returns a new instance of PublicKeyEncryptionCertificates.
5181 5182 5183 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate ⇒ String
X.509 encryption certificate in PEM format. Must only be an end-entity (leaf)
certificate.
Corresponds to the JSON property certificate
5167 5168 5169 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5167 def certificate @certificate end |
#is_default ⇒ Boolean Also known as: is_default?
Whether this is the default certificate for the given email address.
Corresponds to the JSON property is_default
5172 5173 5174 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5172 def is_default @is_default end |
#state ⇒ String
Denotes the certificate's state in its lifecycle. Possible values are
not_yet_validated, valid, invalid, expired, and revoked.
Corresponds to the JSON property state
5179 5180 5181 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5179 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5186 5187 5188 5189 5190 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5186 def update!(**args) @certificate = args[:certificate] if args.key?(:certificate) @is_default = args[:is_default] if args.key?(:is_default) @state = args[:state] if args.key?(:state) end |