Class: Google::Apis::AdminDirectoryV1::UserName
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserName
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Instance Attribute Summary collapse
-
#display_name ⇒ String
The user's display name.
-
#family_name ⇒ String
The user's last name.
-
#full_name ⇒ String
The user's full name formed by concatenating the first and last name values.
-
#given_name ⇒ String
The user's first name.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserName
constructor
A new instance of UserName.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserName
Returns a new instance of UserName.
5491 5492 5493 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5491 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
The user's display name. Limit: 256 characters.
Corresponds to the JSON property displayName
5474 5475 5476 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5474 def display_name @display_name end |
#family_name ⇒ String
The user's last name. Required when creating a user account.
Corresponds to the JSON property familyName
5479 5480 5481 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5479 def family_name @family_name end |
#full_name ⇒ String
The user's full name formed by concatenating the first and last name values.
Corresponds to the JSON property fullName
5484 5485 5486 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5484 def full_name @full_name end |
#given_name ⇒ String
The user's first name. Required when creating a user account.
Corresponds to the JSON property givenName
5489 5490 5491 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5489 def given_name @given_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5496 5497 5498 5499 5500 5501 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5496 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @family_name = args[:family_name] if args.key?(:family_name) @full_name = args[:full_name] if args.key?(:full_name) @given_name = args[:given_name] if args.key?(:given_name) end |