Class: Google::Apis::AdminDirectoryV1::UserPosixAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for a POSIX account entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserPosixAccount

Returns a new instance of UserPosixAccount.



5808
5809
5810
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

A POSIX account field identifier. Corresponds to the JSON property accountId

Returns:

  • (String)


5760
5761
5762
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5760

def 
  @account_id
end

#gecosString

The GECOS (user information) for this account. Corresponds to the JSON property gecos

Returns:

  • (String)


5765
5766
5767
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5765

def gecos
  @gecos
end

#gidFixnum

The default group ID. Corresponds to the JSON property gid

Returns:

  • (Fixnum)


5770
5771
5772
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5770

def gid
  @gid
end

#home_directoryString

The path to the home directory for this account. Corresponds to the JSON property homeDirectory

Returns:

  • (String)


5775
5776
5777
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5775

def home_directory
  @home_directory
end

#operating_system_typeString

The operating system type for this account. Corresponds to the JSON property operatingSystemType

Returns:

  • (String)


5780
5781
5782
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5780

def operating_system_type
  @operating_system_type
end

#primaryBoolean Also known as: primary?

If this is user's primary account within the SystemId. Corresponds to the JSON property primary

Returns:

  • (Boolean)


5785
5786
5787
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5785

def primary
  @primary
end

#shellString

The path to the login shell for this account. Corresponds to the JSON property shell

Returns:

  • (String)


5791
5792
5793
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5791

def shell
  @shell
end

#system_idString

System identifier for which account Username or Uid apply to. Corresponds to the JSON property systemId

Returns:

  • (String)


5796
5797
5798
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5796

def system_id
  @system_id
end

#uidFixnum

The POSIX compliant user ID. Corresponds to the JSON property uid

Returns:

  • (Fixnum)


5801
5802
5803
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5801

def uid
  @uid
end

#usernameString

The username of the account. Corresponds to the JSON property username

Returns:

  • (String)


5806
5807
5808
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5806

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5813
5814
5815
5816
5817
5818
5819
5820
5821
5822
5823
5824
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5813

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @gecos = args[:gecos] if args.key?(:gecos)
  @gid = args[:gid] if args.key?(:gid)
  @home_directory = args[:home_directory] if args.key?(:home_directory)
  @operating_system_type = args[:operating_system_type] if args.key?(:operating_system_type)
  @primary = args[:primary] if args.key?(:primary)
  @shell = args[:shell] if args.key?(:shell)
  @system_id = args[:system_id] if args.key?(:system_id)
  @uid = args[:uid] if args.key?(:uid)
  @username = args[:username] if args.key?(:username)
end