Class: Google::Apis::AdminDirectoryV1::UserWebsite

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for a website entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserWebsite

Returns a new instance of UserWebsite.



5903
5904
5905
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_typeString

Custom Type. Corresponds to the JSON property customType

Returns:

  • (String)


5882
5883
5884
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5882

def custom_type
  @custom_type
end

#primaryBoolean Also known as: primary?

If this is user's primary website or not. Corresponds to the JSON property primary

Returns:

  • (Boolean)


5887
5888
5889
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5887

def primary
  @primary
end

#typeString

Each entry can have a type which indicates standard types of that entry. For example website could be of home work blog etc. In addition to the standard type an entry can have a custom type and can give it any name. Such types should have the CUSTOM value as type and also have a customType value. Corresponds to the JSON property type

Returns:

  • (String)


5896
5897
5898
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5896

def type
  @type
end

#valueString

Website. Corresponds to the JSON property value

Returns:

  • (String)


5901
5902
5903
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5901

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5908
5909
5910
5911
5912
5913
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5908

def update!(**args)
  @custom_type = args[:custom_type] if args.key?(:custom_type)
  @primary = args[:primary] if args.key?(:primary)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end