Class: Google::Apis::AdminDirectoryV1::Users

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Users

Returns a new instance of Users.



5932
5933
5934
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5932

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


5909
5910
5911
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5909

def etag
  @etag
end

#kindString

Kind of resource this is. Corresponds to the JSON property kind

Returns:

  • (String)


5914
5915
5916
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5914

def kind
  @kind
end

#next_page_tokenString

Token used to access next page of this result. The page token is only valid for three days. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5920
5921
5922
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5920

def next_page_token
  @next_page_token
end

#trigger_eventString

Event that triggered this response (only used in case of Push Response) Corresponds to the JSON property trigger_event

Returns:

  • (String)


5925
5926
5927
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5925

def trigger_event
  @trigger_event
end

#usersArray<Google::Apis::AdminDirectoryV1::User>

A list of user objects. Corresponds to the JSON property users



5930
5931
5932
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5930

def users
  @users
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5937
5938
5939
5940
5941
5942
5943
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5937

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @trigger_event = args[:trigger_event] if args.key?(:trigger_event)
  @users = args[:users] if args.key?(:users)
end