Class: Google::Apis::AdminDirectoryV1::VerificationCode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

The Directory API allows you to view, generate, and invalidate backup verification codes for a user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VerificationCode

Returns a new instance of VerificationCode.



6020
6021
6022
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 6020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


6002
6003
6004
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 6002

def etag
  @etag
end

#kindString

The type of the resource. This is always admin#directory#verificationCode. Corresponds to the JSON property kind

Returns:

  • (String)


6007
6008
6009
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 6007

def kind
  @kind
end

#user_idString

The obfuscated unique ID of the user. Corresponds to the JSON property userId

Returns:

  • (String)


6012
6013
6014
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 6012

def user_id
  @user_id
end

#verification_codeString

A current verification code for the user. Invalidated or used verification codes are not returned as part of the result. Corresponds to the JSON property verificationCode

Returns:

  • (String)


6018
6019
6020
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 6018

def verification_code
  @verification_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6025
6026
6027
6028
6029
6030
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 6025

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @user_id = args[:user_id] if args.key?(:user_id)
  @verification_code = args[:verification_code] if args.key?(:verification_code)
end