Class: Google::Apis::AdminDirectoryV1::ChangeChromeOsDeviceStatusResult
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::ChangeChromeOsDeviceStatusResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
The result of a single ChromeOS device for a Change state operation.
Instance Attribute Summary collapse
-
#device_id ⇒ String
The unique ID of the ChromeOS device.
-
#error ⇒ Google::Apis::AdminDirectoryV1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#response ⇒ Google::Apis::AdminDirectoryV1::ChangeChromeOsDeviceStatusSucceeded
Response for a successful ChromeOS device status change.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChangeChromeOsDeviceStatusResult
constructor
A new instance of ChangeChromeOsDeviceStatusResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChangeChromeOsDeviceStatusResult
Returns a new instance of ChangeChromeOsDeviceStatusResult.
897 898 899 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_id ⇒ String
The unique ID of the ChromeOS device.
Corresponds to the JSON property deviceId
880 881 882 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 880 def device_id @device_id end |
#error ⇒ Google::Apis::AdminDirectoryV1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
890 891 892 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 890 def error @error end |
#response ⇒ Google::Apis::AdminDirectoryV1::ChangeChromeOsDeviceStatusSucceeded
Response for a successful ChromeOS device status change.
Corresponds to the JSON property response
895 896 897 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 895 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
902 903 904 905 906 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 902 def update!(**args) @device_id = args[:device_id] if args.key?(:device_id) @error = args[:error] if args.key?(:error) @response = args[:response] if args.key?(:response) end |