Class: Google::Apis::AdminDirectoryV1::ChromeOsDevice
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::ChromeOsDevice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Google Chrome devices run on the Chrome OS. For more information about common API tasks, see the Developer's Guide.
Defined Under Namespace
Classes: ActiveTimeRange, CpuInfo, CpuStatusReport, DeviceFile, DiskVolumeReport, LastKnownNetwork, RecentUser, ScreenshotFile, SystemRamFreeReport, TpmVersionInfo
Instance Attribute Summary collapse
-
#active_time_ranges ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::ActiveTimeRange>
A list of active time ranges (Read-only).
-
#annotated_asset_id ⇒ String
The asset identifier as noted by an administrator or specified during enrollment.
-
#annotated_location ⇒ String
The address or location of the device as noted by the administrator.
-
#annotated_user ⇒ String
The user of the device as noted by the administrator.
-
#auto_update_expiration ⇒ Fixnum
(Read-only) The timestamp after which the device will stop receiving Chrome updates or support.
-
#auto_update_through ⇒ String
Output only.
-
#backlight_info ⇒ Array<Google::Apis::AdminDirectoryV1::BacklightInfo>
Output only.
-
#bluetooth_adapter_info ⇒ Array<Google::Apis::AdminDirectoryV1::BluetoothAdapterInfo>
Output only.
-
#boot_mode ⇒ String
The boot mode for the device.
-
#chrome_os_type ⇒ String
Output only.
-
#cpu_info ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::CpuInfo>
Information regarding CPU specs in the device.
-
#cpu_status_reports ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::CpuStatusReport>
Reports of CPU utilization and temperature (Read-only) Corresponds to the JSON property
cpuStatusReports. -
#deprovision_reason ⇒ String
(Read-only) Deprovision reason.
-
#device_files ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::DeviceFile>
A list of device files to download (Read-only) Corresponds to the JSON property
deviceFiles. -
#device_id ⇒ String
The unique ID of the Chrome device.
-
#device_license_type ⇒ String
Output only.
-
#disk_space_usage ⇒ Google::Apis::AdminDirectoryV1::ByteUsage
Represents a data capacity with some amount of current usage in bytes.
-
#disk_volume_reports ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::DiskVolumeReport>
Reports of disk space and other info about mounted/connected volumes.
-
#dock_mac_address ⇒ String
(Read-only) Built-in MAC address for the docking station that the device connected to.
-
#etag ⇒ String
ETag of the resource.
-
#ethernet_mac_address ⇒ String
The device's MAC address on the ethernet network interface.
-
#ethernet_mac_address0 ⇒ String
(Read-only) MAC address used by the Chromebook’s internal ethernet port, and for onboard network (ethernet) interface.
-
#extended_support_eligible ⇒ Boolean
(also: #extended_support_eligible?)
Output only.
-
#extended_support_enabled ⇒ Boolean
(also: #extended_support_enabled?)
Output only.
-
#extended_support_start ⇒ String
Output only.
-
#fan_info ⇒ Array<Google::Apis::AdminDirectoryV1::FanInfo>
Output only.
-
#firmware_version ⇒ String
The Chrome device's firmware version.
-
#first_enrollment_time ⇒ String
Date and time for the first time the device was enrolled.
-
#kind ⇒ String
The type of resource.
-
#last_deprovision_timestamp ⇒ String
(Read-only) Date and time for the last deprovision of the device.
-
#last_enrollment_time ⇒ DateTime
Date and time the device was last enrolled (Read-only) Corresponds to the JSON property
lastEnrollmentTime. -
#last_known_network ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::LastKnownNetwork>
Contains last known network (Read-only) Corresponds to the JSON property
lastKnownNetwork. -
#last_sync ⇒ DateTime
Date and time the device was last synchronized with the policy settings in the G Suite administrator control panel (Read-only) Corresponds to the JSON property
lastSync. -
#mac_address ⇒ String
The device's wireless MAC address.
-
#manufacture_date ⇒ String
(Read-only) The date the device was manufactured in yyyy-mm-dd format.
-
#meid ⇒ String
The Mobile Equipment Identifier (MEID) or the International Mobile Equipment Identity (IMEI) for the 3G mobile card in a mobile device.
-
#model ⇒ String
The device's model information.
-
#notes ⇒ String
Notes about this device added by the administrator.
-
#order_number ⇒ String
The device's order number.
-
#org_unit_id ⇒ String
The unique ID of the organizational unit.
-
#org_unit_path ⇒ String
The full parent path with the organizational unit's name associated with the device.
-
#os_update_status ⇒ Google::Apis::AdminDirectoryV1::OsUpdateStatus
Contains information regarding the current OS update status.
-
#os_version ⇒ String
The Chrome device's operating system version.
-
#os_version_compliance ⇒ String
Output only.
-
#platform_version ⇒ String
The Chrome device's platform version.
-
#recent_users ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::RecentUser>
A list of recent device users, in descending order, by last login time.
-
#screenshot_files ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::ScreenshotFile>
A list of screenshot files to download.
-
#serial_number ⇒ String
The Chrome device serial number entered when the device was enabled.
-
#status ⇒ String
The status of the device.
-
#support_end_date ⇒ DateTime
Final date the device will be supported (Read-only) Corresponds to the JSON property
supportEndDate. -
#system_ram_free_reports ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::SystemRamFreeReport>
Reports of amounts of available RAM memory (Read-only) Corresponds to the JSON property
systemRamFreeReports. -
#system_ram_total ⇒ Fixnum
Total RAM on the device in bytes Corresponds to the JSON property
systemRamTotal. -
#tpm_version_info ⇒ Google::Apis::AdminDirectoryV1::ChromeOsDevice::TpmVersionInfo
Trusted Platform Module (TPM) (Read-only) Corresponds to the JSON property
tpmVersionInfo. -
#will_auto_renew ⇒ Boolean
(also: #will_auto_renew?)
Determines if the device will auto renew its support after the support end date.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ChromeOsDevice
constructor
A new instance of ChromeOsDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ChromeOsDevice
Returns a new instance of ChromeOsDevice.
1335 1336 1337 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#active_time_ranges ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::ActiveTimeRange>
A list of active time ranges (Read-only).
Corresponds to the JSON property activeTimeRanges
1013 1014 1015 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1013 def active_time_ranges @active_time_ranges end |
#annotated_asset_id ⇒ String
The asset identifier as noted by an administrator or specified during
enrollment.
Corresponds to the JSON property annotatedAssetId
1019 1020 1021 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1019 def annotated_asset_id @annotated_asset_id end |
#annotated_location ⇒ String
The address or location of the device as noted by the administrator. Maximum
length is 200 characters. Empty values are allowed.
Corresponds to the JSON property annotatedLocation
1025 1026 1027 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1025 def annotated_location @annotated_location end |
#annotated_user ⇒ String
The user of the device as noted by the administrator. Maximum length is 100
characters. Empty values are allowed.
Corresponds to the JSON property annotatedUser
1031 1032 1033 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1031 def annotated_user @annotated_user end |
#auto_update_expiration ⇒ Fixnum
(Read-only) The timestamp after which the device will stop receiving Chrome
updates or support. Please use "autoUpdateThrough" instead.
Corresponds to the JSON property autoUpdateExpiration
1037 1038 1039 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1037 def auto_update_expiration @auto_update_expiration end |
#auto_update_through ⇒ String
Output only. The timestamp after which the device will stop receiving Chrome
updates or support.
Corresponds to the JSON property autoUpdateThrough
1043 1044 1045 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1043 def auto_update_through @auto_update_through end |
#backlight_info ⇒ Array<Google::Apis::AdminDirectoryV1::BacklightInfo>
Output only. Contains backlight information for the device.
Corresponds to the JSON property backlightInfo
1048 1049 1050 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1048 def backlight_info @backlight_info end |
#bluetooth_adapter_info ⇒ Array<Google::Apis::AdminDirectoryV1::BluetoothAdapterInfo>
Output only. Information about Bluetooth adapters of the device.
Corresponds to the JSON property bluetoothAdapterInfo
1053 1054 1055 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1053 def bluetooth_adapter_info @bluetooth_adapter_info end |
#boot_mode ⇒ String
The boot mode for the device. The possible values are: * Verified: The
device is running a valid version of the Chrome OS. * Dev: The devices's
developer hardware switch is enabled. When booted, the device has a command
line shell. For an example of a developer switch, see the Chromebook
developer information.
Corresponds to the JSON property bootMode
1064 1065 1066 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1064 def boot_mode @boot_mode end |
#chrome_os_type ⇒ String
Output only. Chrome OS type of the device.
Corresponds to the JSON property chromeOsType
1069 1070 1071 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1069 def chrome_os_type @chrome_os_type end |
#cpu_info ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::CpuInfo>
Information regarding CPU specs in the device.
Corresponds to the JSON property cpuInfo
1074 1075 1076 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1074 def cpu_info @cpu_info end |
#cpu_status_reports ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::CpuStatusReport>
Reports of CPU utilization and temperature (Read-only)
Corresponds to the JSON property cpuStatusReports
1079 1080 1081 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1079 def cpu_status_reports @cpu_status_reports end |
#deprovision_reason ⇒ String
(Read-only) Deprovision reason.
Corresponds to the JSON property deprovisionReason
1084 1085 1086 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1084 def deprovision_reason @deprovision_reason end |
#device_files ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::DeviceFile>
A list of device files to download (Read-only)
Corresponds to the JSON property deviceFiles
1089 1090 1091 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1089 def device_files @device_files end |
#device_id ⇒ String
The unique ID of the Chrome device.
Corresponds to the JSON property deviceId
1094 1095 1096 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1094 def device_id @device_id end |
#device_license_type ⇒ String
Output only. Device license type.
Corresponds to the JSON property deviceLicenseType
1099 1100 1101 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1099 def device_license_type @device_license_type end |
#disk_space_usage ⇒ Google::Apis::AdminDirectoryV1::ByteUsage
Represents a data capacity with some amount of current usage in bytes.
Corresponds to the JSON property diskSpaceUsage
1104 1105 1106 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1104 def disk_space_usage @disk_space_usage end |
#disk_volume_reports ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::DiskVolumeReport>
Reports of disk space and other info about mounted/connected volumes.
Corresponds to the JSON property diskVolumeReports
1109 1110 1111 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1109 def disk_volume_reports @disk_volume_reports end |
#dock_mac_address ⇒ String
(Read-only) Built-in MAC address for the docking station that the device
connected to. Factory sets Media access control address (MAC address) assigned
for use by a dock. It is reserved specifically for MAC pass through device
policy. The format is twelve (12) hexadecimal digits without any delimiter (
uppercase letters). This is only relevant for some devices.
Corresponds to the JSON property dockMacAddress
1118 1119 1120 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1118 def dock_mac_address @dock_mac_address end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
1123 1124 1125 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1123 def etag @etag end |
#ethernet_mac_address ⇒ String
The device's MAC address on the ethernet network interface.
Corresponds to the JSON property ethernetMacAddress
1128 1129 1130 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1128 def ethernet_mac_address @ethernet_mac_address end |
#ethernet_mac_address0 ⇒ String
(Read-only) MAC address used by the Chromebook’s internal ethernet port, and
for onboard network (ethernet) interface. The format is twelve (12)
hexadecimal digits without any delimiter (uppercase letters). This is only
relevant for some devices.
Corresponds to the JSON property ethernetMacAddress0
1136 1137 1138 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1136 def ethernet_mac_address0 @ethernet_mac_address0 end |
#extended_support_eligible ⇒ Boolean Also known as: extended_support_eligible?
Output only. Whether or not the device requires the extended support opt in.
Corresponds to the JSON property extendedSupportEligible
1141 1142 1143 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1141 def extended_support_eligible @extended_support_eligible end |
#extended_support_enabled ⇒ Boolean Also known as: extended_support_enabled?
Output only. Whether extended support policy is enabled on the device.
Corresponds to the JSON property extendedSupportEnabled
1147 1148 1149 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1147 def extended_support_enabled @extended_support_enabled end |
#extended_support_start ⇒ String
Output only. Date of the device when extended support policy for automatic
updates starts.
Corresponds to the JSON property extendedSupportStart
1154 1155 1156 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1154 def extended_support_start @extended_support_start end |
#fan_info ⇒ Array<Google::Apis::AdminDirectoryV1::FanInfo>
Output only. Fan information for the device.
Corresponds to the JSON property fanInfo
1159 1160 1161 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1159 def fan_info @fan_info end |
#firmware_version ⇒ String
The Chrome device's firmware version.
Corresponds to the JSON property firmwareVersion
1164 1165 1166 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1164 def firmware_version @firmware_version end |
#first_enrollment_time ⇒ String
Date and time for the first time the device was enrolled.
Corresponds to the JSON property firstEnrollmentTime
1169 1170 1171 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1169 def first_enrollment_time @first_enrollment_time end |
#kind ⇒ String
The type of resource. For the Chromeosdevices resource, the value is admin#
directory#chromeosdevice.
Corresponds to the JSON property kind
1175 1176 1177 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1175 def kind @kind end |
#last_deprovision_timestamp ⇒ String
(Read-only) Date and time for the last deprovision of the device.
Corresponds to the JSON property lastDeprovisionTimestamp
1180 1181 1182 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1180 def @last_deprovision_timestamp end |
#last_enrollment_time ⇒ DateTime
Date and time the device was last enrolled (Read-only)
Corresponds to the JSON property lastEnrollmentTime
1185 1186 1187 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1185 def last_enrollment_time @last_enrollment_time end |
#last_known_network ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::LastKnownNetwork>
Contains last known network (Read-only)
Corresponds to the JSON property lastKnownNetwork
1190 1191 1192 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1190 def last_known_network @last_known_network end |
#last_sync ⇒ DateTime
Date and time the device was last synchronized with the policy settings in the
G Suite administrator control panel (Read-only)
Corresponds to the JSON property lastSync
1196 1197 1198 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1196 def last_sync @last_sync end |
#mac_address ⇒ String
The device's wireless MAC address. If the device does not have this
information, it is not included in the response.
Corresponds to the JSON property macAddress
1202 1203 1204 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1202 def mac_address @mac_address end |
#manufacture_date ⇒ String
(Read-only) The date the device was manufactured in yyyy-mm-dd format.
Corresponds to the JSON property manufactureDate
1207 1208 1209 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1207 def manufacture_date @manufacture_date end |
#meid ⇒ String
The Mobile Equipment Identifier (MEID) or the International Mobile Equipment
Identity (IMEI) for the 3G mobile card in a mobile device. A MEID/IMEI is
typically used when adding a device to a wireless carrier's post-pay service
plan. If the device does not have this information, this property is not
included in the response. For more information on how to export a MEID/IMEI
list, see the Developer's Guide.
Corresponds to the JSON property meid
1218 1219 1220 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1218 def meid @meid end |
#model ⇒ String
The device's model information. If the device does not have this information,
this property is not included in the response.
Corresponds to the JSON property model
1224 1225 1226 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1224 def model @model end |
#notes ⇒ String
1233 1234 1235 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1233 def notes @notes end |
#order_number ⇒ String
The device's order number. Only devices directly purchased from Google have an
order number.
Corresponds to the JSON property orderNumber
1239 1240 1241 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1239 def order_number @order_number end |
#org_unit_id ⇒ String
The unique ID of the organizational unit. orgUnitPath is the human readable
version of orgUnitId. While orgUnitPath may change by renaming an
organizational unit within the path, orgUnitId is unchangeable for one
organizational unit. This property can be updated using the API. For more information about how to
create an organizational structure for your device, see the administration
help center.
Corresponds to the JSON property orgUnitId
1251 1252 1253 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1251 def org_unit_id @org_unit_id end |
#org_unit_path ⇒ String
The full parent path with the organizational unit's name associated with the
device. Path names are case insensitive. If the parent organizational unit is
the top-level organization, it is represented as a forward slash, /. This
property can be updated using the
API. For more information about how to create an organizational structure for
your device, see the administration help center.
Corresponds to the JSON property orgUnitPath
1263 1264 1265 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1263 def org_unit_path @org_unit_path end |
#os_update_status ⇒ Google::Apis::AdminDirectoryV1::OsUpdateStatus
Contains information regarding the current OS update status.
Corresponds to the JSON property osUpdateStatus
1268 1269 1270 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1268 def os_update_status @os_update_status end |
#os_version ⇒ String
The Chrome device's operating system version.
Corresponds to the JSON property osVersion
1273 1274 1275 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1273 def os_version @os_version end |
#os_version_compliance ⇒ String
Output only. Device policy compliance status of the OS version.
Corresponds to the JSON property osVersionCompliance
1278 1279 1280 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1278 def os_version_compliance @os_version_compliance end |
#platform_version ⇒ String
The Chrome device's platform version.
Corresponds to the JSON property platformVersion
1283 1284 1285 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1283 def platform_version @platform_version end |
#recent_users ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::RecentUser>
A list of recent device users, in descending order, by last login time.
Corresponds to the JSON property recentUsers
1288 1289 1290 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1288 def recent_users @recent_users end |
#screenshot_files ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::ScreenshotFile>
A list of screenshot files to download. Type is always "SCREENSHOT_FILE". (
Read-only)
Corresponds to the JSON property screenshotFiles
1294 1295 1296 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1294 def screenshot_files @screenshot_files end |
#serial_number ⇒ String
The Chrome device serial number entered when the device was enabled. This
value is the same as the Admin console's Serial Number in the Chrome OS
Devices tab.
Corresponds to the JSON property serialNumber
1301 1302 1303 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1301 def serial_number @serial_number end |
#status ⇒ String
The status of the device.
Corresponds to the JSON property status
1306 1307 1308 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1306 def status @status end |
#support_end_date ⇒ DateTime
Final date the device will be supported (Read-only)
Corresponds to the JSON property supportEndDate
1311 1312 1313 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1311 def support_end_date @support_end_date end |
#system_ram_free_reports ⇒ Array<Google::Apis::AdminDirectoryV1::ChromeOsDevice::SystemRamFreeReport>
Reports of amounts of available RAM memory (Read-only)
Corresponds to the JSON property systemRamFreeReports
1316 1317 1318 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1316 def system_ram_free_reports @system_ram_free_reports end |
#system_ram_total ⇒ Fixnum
Total RAM on the device in bytes
Corresponds to the JSON property systemRamTotal
1321 1322 1323 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1321 def system_ram_total @system_ram_total end |
#tpm_version_info ⇒ Google::Apis::AdminDirectoryV1::ChromeOsDevice::TpmVersionInfo
Trusted Platform Module (TPM) (Read-only)
Corresponds to the JSON property tpmVersionInfo
1326 1327 1328 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1326 def tpm_version_info @tpm_version_info end |
#will_auto_renew ⇒ Boolean Also known as: will_auto_renew?
Determines if the device will auto renew its support after the support end
date. This is a read-only property.
Corresponds to the JSON property willAutoRenew
1332 1333 1334 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1332 def will_auto_renew @will_auto_renew end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 1356 1357 1358 1359 1360 1361 1362 1363 1364 1365 1366 1367 1368 1369 1370 1371 1372 1373 1374 1375 1376 1377 1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 1340 def update!(**args) @active_time_ranges = args[:active_time_ranges] if args.key?(:active_time_ranges) @annotated_asset_id = args[:annotated_asset_id] if args.key?(:annotated_asset_id) @annotated_location = args[:annotated_location] if args.key?(:annotated_location) @annotated_user = args[:annotated_user] if args.key?(:annotated_user) @auto_update_expiration = args[:auto_update_expiration] if args.key?(:auto_update_expiration) @auto_update_through = args[:auto_update_through] if args.key?(:auto_update_through) @backlight_info = args[:backlight_info] if args.key?(:backlight_info) @bluetooth_adapter_info = args[:bluetooth_adapter_info] if args.key?(:bluetooth_adapter_info) @boot_mode = args[:boot_mode] if args.key?(:boot_mode) @chrome_os_type = args[:chrome_os_type] if args.key?(:chrome_os_type) @cpu_info = args[:cpu_info] if args.key?(:cpu_info) @cpu_status_reports = args[:cpu_status_reports] if args.key?(:cpu_status_reports) @deprovision_reason = args[:deprovision_reason] if args.key?(:deprovision_reason) @device_files = args[:device_files] if args.key?(:device_files) @device_id = args[:device_id] if args.key?(:device_id) @device_license_type = args[:device_license_type] if args.key?(:device_license_type) @disk_space_usage = args[:disk_space_usage] if args.key?(:disk_space_usage) @disk_volume_reports = args[:disk_volume_reports] if args.key?(:disk_volume_reports) @dock_mac_address = args[:dock_mac_address] if args.key?(:dock_mac_address) @etag = args[:etag] if args.key?(:etag) @ethernet_mac_address = args[:ethernet_mac_address] if args.key?(:ethernet_mac_address) @ethernet_mac_address0 = args[:ethernet_mac_address0] if args.key?(:ethernet_mac_address0) @extended_support_eligible = args[:extended_support_eligible] if args.key?(:extended_support_eligible) @extended_support_enabled = args[:extended_support_enabled] if args.key?(:extended_support_enabled) @extended_support_start = args[:extended_support_start] if args.key?(:extended_support_start) @fan_info = args[:fan_info] if args.key?(:fan_info) @firmware_version = args[:firmware_version] if args.key?(:firmware_version) @first_enrollment_time = args[:first_enrollment_time] if args.key?(:first_enrollment_time) @kind = args[:kind] if args.key?(:kind) @last_deprovision_timestamp = args[:last_deprovision_timestamp] if args.key?(:last_deprovision_timestamp) @last_enrollment_time = args[:last_enrollment_time] if args.key?(:last_enrollment_time) @last_known_network = args[:last_known_network] if args.key?(:last_known_network) @last_sync = args[:last_sync] if args.key?(:last_sync) @mac_address = args[:mac_address] if args.key?(:mac_address) @manufacture_date = args[:manufacture_date] if args.key?(:manufacture_date) @meid = args[:meid] if args.key?(:meid) @model = args[:model] if args.key?(:model) @notes = args[:notes] if args.key?(:notes) @order_number = args[:order_number] if args.key?(:order_number) @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id) @org_unit_path = args[:org_unit_path] if args.key?(:org_unit_path) @os_update_status = args[:os_update_status] if args.key?(:os_update_status) @os_version = args[:os_version] if args.key?(:os_version) @os_version_compliance = args[:os_version_compliance] if args.key?(:os_version_compliance) @platform_version = args[:platform_version] if args.key?(:platform_version) @recent_users = args[:recent_users] if args.key?(:recent_users) @screenshot_files = args[:screenshot_files] if args.key?(:screenshot_files) @serial_number = args[:serial_number] if args.key?(:serial_number) @status = args[:status] if args.key?(:status) @support_end_date = args[:support_end_date] if args.key?(:support_end_date) @system_ram_free_reports = args[:system_ram_free_reports] if args.key?(:system_ram_free_reports) @system_ram_total = args[:system_ram_total] if args.key?(:system_ram_total) @tpm_version_info = args[:tpm_version_info] if args.key?(:tpm_version_info) @will_auto_renew = args[:will_auto_renew] if args.key?(:will_auto_renew) end |