Class: Google::Apis::AdminDirectoryV1::DirectoryChromeosdevicesCommandResult
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::DirectoryChromeosdevicesCommandResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
The result of executing a command.
Instance Attribute Summary collapse
-
#command_result_payload ⇒ String
The payload for the command result.
-
#error_message ⇒ String
The error message with a short explanation as to why the command failed.
-
#execute_time ⇒ String
The time at which the command was executed or failed to execute.
-
#result ⇒ String
The result of the command.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DirectoryChromeosdevicesCommandResult
constructor
A new instance of DirectoryChromeosdevicesCommandResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DirectoryChromeosdevicesCommandResult
Returns a new instance of DirectoryChromeosdevicesCommandResult.
2224 2225 2226 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#command_result_payload ⇒ String
The payload for the command result. The following commands respond with a
payload: * DEVICE_START_CRD_SESSION: Payload is a stringified JSON object in
the form: "url": url. The provided URL links to the Chrome Remote Desktop
session and requires authentication using only the email associated with the
command's issuance. * FETCH_CRD_AVAILABILITY_INFO: Payload is a stringified
JSON object in the form: "deviceIdleTimeInSeconds": number, "userSessionType"
: string, "remoteSupportAvailability": string, "remoteAccessAvailability":
string. The "remoteSupportAvailability" field is set to "AVAILABLE" if
shared CRD session to the device is available. The "remoteAccessAvailability"
field is set to "AVAILABLE" if private CRD session to the device is
available.
Corresponds to the JSON property commandResultPayload
2206 2207 2208 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2206 def command_result_payload @command_result_payload end |
#error_message ⇒ String
The error message with a short explanation as to why the command failed. Only
present if the command failed.
Corresponds to the JSON property errorMessage
2212 2213 2214 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2212 def @error_message end |
#execute_time ⇒ String
The time at which the command was executed or failed to execute.
Corresponds to the JSON property executeTime
2217 2218 2219 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2217 def execute_time @execute_time end |
#result ⇒ String
The result of the command.
Corresponds to the JSON property result
2222 2223 2224 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2222 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2229 2230 2231 2232 2233 2234 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2229 def update!(**args) @command_result_payload = args[:command_result_payload] if args.key?(:command_result_payload) @error_message = args[:error_message] if args.key?(:error_message) @execute_time = args[:execute_time] if args.key?(:execute_time) @result = args[:result] if args.key?(:result) end |