Class: Google::Apis::AdminDirectoryV1::ExternalId
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::ExternalId
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
External identifier used to link and identify this group across external directory systems.
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier string assigned by the external provider.
-
#namespace ⇒ String
The system or identity provider managing this ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalId
constructor
A new instance of ExternalId.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalId
Returns a new instance of ExternalId.
2543 2544 2545 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2543 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier string assigned by the external provider.
Corresponds to the JSON property id
2536 2537 2538 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2536 def id @id end |
#namespace ⇒ String
The system or identity provider managing this ID.
Corresponds to the JSON property namespace
2541 2542 2543 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2541 def namespace @namespace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2548 2549 2550 2551 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2548 def update!(**args) @id = args[:id] if args.key?(:id) @namespace = args[:namespace] if args.key?(:namespace) end |