Class: Google::Apis::AdminDirectoryV1::Group

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Google Groups provide your users the ability to send messages to groups of people using the group's email address. For more information about common tasks, see the Developer's Guide. For information about other types of groups, see the Cloud Identity Groups API documentation. Note: The user calling the API (or being impersonated by a service account) must have an assigned role that includes Admin API Groups permissions, such as Super Admin or Groups Admin.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Group

Returns a new instance of Group.



2772
2773
2774
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_createdBoolean Also known as: admin_created?

Read-only. Value is true if this group was created by an administrator rather than a user. Corresponds to the JSON property adminCreated

Returns:

  • (Boolean)


2707
2708
2709
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2707

def admin_created
  @admin_created
end

#aliasesArray<String>

Read-only. The list of a group's alias email addresses. To add, update, or remove a group's aliases, use the groups.aliases methods. If edited in a group's POST or PUT request, the edit is ignored. Corresponds to the JSON property aliases

Returns:

  • (Array<String>)


2715
2716
2717
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2715

def aliases
  @aliases
end

#descriptionString

An extended description to help users determine the purpose of a group. For example, you can include information about who should join the group, the types of messages to send to the group, links to FAQs about the group, or related groups. Maximum length is 4,096 characters. Corresponds to the JSON property description

Returns:

  • (String)


2723
2724
2725
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2723

def description
  @description
end

#direct_members_countFixnum

The number of users that are direct members of the group. If a group is a member (child) of this group (the parent), members of the child group are not counted in the directMembersCount property of the parent group. Corresponds to the JSON property directMembersCount

Returns:

  • (Fixnum)


2730
2731
2732
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2730

def direct_members_count
  @direct_members_count
end

#emailString

The group's email address. If your account has multiple domains, select the appropriate domain for the email address. The email must be unique. This property is required when creating a group. Group email addresses are subject to the same character usage rules as usernames, see the help center for details. Corresponds to the JSON property email

Returns:

  • (String)


2739
2740
2741
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2739

def email
  @email
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


2744
2745
2746
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2744

def etag
  @etag
end

#idString

Read-only. The unique ID of a group. A group id can be used as a group request URI's groupKey. Corresponds to the JSON property id

Returns:

  • (String)


2750
2751
2752
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2750

def id
  @id
end

#kindString

The type of the API resource. For Groups resources, the value is admin# directory#group. Corresponds to the JSON property kind

Returns:

  • (String)


2756
2757
2758
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2756

def kind
  @kind
end

#nameString

The group's display name. Corresponds to the JSON property name

Returns:

  • (String)


2761
2762
2763
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2761

def name
  @name
end

#non_editable_aliasesArray<String>

Read-only. The list of the group's non-editable alias email addresses that are outside of the account's primary domain or subdomains. These are functioning email addresses used by the group. This is a read-only property returned in the API's response for a group. If edited in a group's POST or PUT request, the edit is ignored. Corresponds to the JSON property nonEditableAliases

Returns:

  • (Array<String>)


2770
2771
2772
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2770

def non_editable_aliases
  @non_editable_aliases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2777

def update!(**args)
  @admin_created = args[:admin_created] if args.key?(:admin_created)
  @aliases = args[:aliases] if args.key?(:aliases)
  @description = args[:description] if args.key?(:description)
  @direct_members_count = args[:direct_members_count] if args.key?(:direct_members_count)
  @email = args[:email] if args.key?(:email)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @non_editable_aliases = args[:non_editable_aliases] if args.key?(:non_editable_aliases)
end