Class: Google::Apis::AdminDirectoryV1::Member
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::Member
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
A Google Groups member can be a user or another group. This member can be inside or outside of your account's domains. For more information about common group member tasks, see the Developer's Guide.
Instance Attribute Summary collapse
-
#delivery_settings ⇒ String
Defines mail delivery preferences of member.
-
#email ⇒ String
The member's email address.
-
#etag ⇒ String
ETag of the resource.
-
#id ⇒ String
The unique ID of the group member.
-
#kind ⇒ String
The type of the API resource.
-
#role ⇒ String
The member's role in a group.
-
#status ⇒ String
Status of member (Immutable) Corresponds to the JSON property
status. -
#type ⇒ String
The type of group member.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Member
constructor
A new instance of Member.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Member
Returns a new instance of Member.
3028 3029 3030 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delivery_settings ⇒ String
Defines mail delivery preferences of member. This field is only supported by
insert, update, and get methods.
Corresponds to the JSON property delivery_settings
2983 2984 2985 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2983 def delivery_settings @delivery_settings end |
#email ⇒ String
The member's email address. A member can be a user or another group. This
property is required when adding a member to a group. The email must be
unique and cannot be an alias of another group. If the email address is
changed, the API automatically reflects the email address changes.
Corresponds to the JSON property email
2991 2992 2993 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2991 def email @email end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
2996 2997 2998 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2996 def etag @etag end |
#id ⇒ String
The unique ID of the group member. A member id can be used as a member
request URI's memberKey.
Corresponds to the JSON property id
3002 3003 3004 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3002 def id @id end |
#kind ⇒ String
The type of the API resource. For Members resources, the value is admin#
directory#member.
Corresponds to the JSON property kind
3008 3009 3010 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3008 def kind @kind end |
#role ⇒ String
The member's role in a group. The API returns an error for cycles in group
memberships. For example, if group1 is a member of group2, group2 cannot
be a member of group1. For more information about a member's role, see the
administration help center.
Corresponds to the JSON property role
3016 3017 3018 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3016 def role @role end |
#status ⇒ String
Status of member (Immutable)
Corresponds to the JSON property status
3021 3022 3023 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3021 def status @status end |
#type ⇒ String
The type of group member.
Corresponds to the JSON property type
3026 3027 3028 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3026 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3033 3034 3035 3036 3037 3038 3039 3040 3041 3042 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3033 def update!(**args) @delivery_settings = args[:delivery_settings] if args.key?(:delivery_settings) @email = args[:email] if args.key?(:email) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @role = args[:role] if args.key?(:role) @status = args[:status] if args.key?(:status) @type = args[:type] if args.key?(:type) end |