Class: Google::Apis::AdminDirectoryV1::Member

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

A Google Groups member can be a user or another group. This member can be inside or outside of your account's domains. For more information about common group member tasks, see the Developer's Guide.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Member

Returns a new instance of Member.



3026
3027
3028
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3026

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delivery_settingsString

Defines mail delivery preferences of member. This field is only supported by insert, update, and get methods. Corresponds to the JSON property delivery_settings

Returns:

  • (String)


2981
2982
2983
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2981

def delivery_settings
  @delivery_settings
end

#emailString

The member's email address. A member can be a user or another group. This property is required when adding a member to a group. The email must be unique and cannot be an alias of another group. If the email address is changed, the API automatically reflects the email address changes. Corresponds to the JSON property email

Returns:

  • (String)


2989
2990
2991
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2989

def email
  @email
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


2994
2995
2996
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 2994

def etag
  @etag
end

#idString

The unique ID of the group member. A member id can be used as a member request URI's memberKey. Corresponds to the JSON property id

Returns:

  • (String)


3000
3001
3002
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3000

def id
  @id
end

#kindString

The type of the API resource. For Members resources, the value is admin# directory#member. Corresponds to the JSON property kind

Returns:

  • (String)


3006
3007
3008
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3006

def kind
  @kind
end

#roleString

The member's role in a group. The API returns an error for cycles in group memberships. For example, if group1 is a member of group2, group2 cannot be a member of group1. For more information about a member's role, see the administration help center. Corresponds to the JSON property role

Returns:

  • (String)


3014
3015
3016
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3014

def role
  @role
end

#statusString

Status of member (Immutable) Corresponds to the JSON property status

Returns:

  • (String)


3019
3020
3021
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3019

def status
  @status
end

#typeString

The type of group member. Corresponds to the JSON property type

Returns:

  • (String)


3024
3025
3026
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3024

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3031
3032
3033
3034
3035
3036
3037
3038
3039
3040
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3031

def update!(**args)
  @delivery_settings = args[:delivery_settings] if args.key?(:delivery_settings)
  @email = args[:email] if args.key?(:email)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @role = args[:role] if args.key?(:role)
  @status = args[:status] if args.key?(:status)
  @type = args[:type] if args.key?(:type)
end