Class: Google::Apis::AdminDirectoryV1::MobileDevice
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::MobileDevice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Google Workspace Mobile Management includes Android, Google Sync, and iOS devices. For more information about common group mobile device API tasks, see the Developer's Guide.
Defined Under Namespace
Classes: Application
Instance Attribute Summary collapse
-
#adb_status ⇒ Boolean
(also: #adb_status?)
Adb (USB debugging) enabled or disabled on device (Read-only) Corresponds to the JSON property
adbStatus. -
#applications ⇒ Array<Google::Apis::AdminDirectoryV1::MobileDevice::Application>
The list of applications installed on an Android mobile device.
-
#baseband_version ⇒ String
The device's baseband version.
-
#bootloader_version ⇒ String
Mobile Device Bootloader version (Read-only) Corresponds to the JSON property
bootloaderVersion. -
#brand ⇒ String
Mobile Device Brand (Read-only) Corresponds to the JSON property
brand. -
#build_number ⇒ String
The device's operating system build number.
-
#default_language ⇒ String
The default locale used on the device.
-
#developer_options_status ⇒ Boolean
(also: #developer_options_status?)
Developer options enabled or disabled on device (Read-only) Corresponds to the JSON property
developerOptionsStatus. -
#device_compromised_status ⇒ String
The compromised device status.
-
#device_id ⇒ String
The serial number for a Google Sync mobile device.
-
#device_password_status ⇒ String
DevicePasswordStatus (Read-only) Corresponds to the JSON property
devicePasswordStatus. -
#email ⇒ Array<String>
The list of the owner's email addresses.
-
#encryption_status ⇒ String
Mobile Device Encryption Status (Read-only) Corresponds to the JSON property
encryptionStatus. -
#etag ⇒ String
ETag of the resource.
-
#first_sync ⇒ DateTime
Date and time the device was first synchronized with the policy settings in the G Suite administrator control panel (Read-only) Corresponds to the JSON property
firstSync. -
#hardware ⇒ String
Mobile Device Hardware (Read-only) Corresponds to the JSON property
hardware. -
#hardware_id ⇒ String
The IMEI/MEID unique identifier for Android hardware.
-
#imei ⇒ String
The device's IMEI number.
-
#kernel_version ⇒ String
The device's kernel version.
-
#kind ⇒ String
The type of the API resource.
-
#last_sync ⇒ DateTime
Date and time the device was last synchronized with the policy settings in the G Suite administrator control panel (Read-only) Corresponds to the JSON property
lastSync. -
#managed_account_is_on_owner_profile ⇒ Boolean
(also: #managed_account_is_on_owner_profile?)
Boolean indicating if this account is on owner/primary profile or not.
-
#manufacturer ⇒ String
Mobile Device manufacturer (Read-only) Corresponds to the JSON property
manufacturer. -
#meid ⇒ String
The device's MEID number.
-
#model ⇒ String
The mobile device's model name, for example Nexus S.
-
#name ⇒ Array<String>
The list of the owner's user names.
-
#network_operator ⇒ String
Mobile Device mobile or network operator (if available) (Read-only) Corresponds to the JSON property
networkOperator. -
#os ⇒ String
The mobile device's operating system, for example IOS 4.3 or Android 2.3.5.
-
#other_accounts_info ⇒ Array<String>
The list of accounts added on device (Read-only) Corresponds to the JSON property
otherAccountsInfo. -
#privilege ⇒ String
DMAgentPermission (Read-only) Corresponds to the JSON property
privilege. -
#release_version ⇒ String
Mobile Device release version version (Read-only) Corresponds to the JSON property
releaseVersion. -
#resource_id ⇒ String
The unique ID the API service uses to identify the mobile device.
-
#security_patch_level ⇒ Fixnum
Mobile Device Security patch level (Read-only) Corresponds to the JSON property
securityPatchLevel. -
#serial_number ⇒ String
The device's serial number.
-
#status ⇒ String
The device's status.
-
#supports_work_profile ⇒ Boolean
(also: #supports_work_profile?)
Work profile supported on device (Read-only) Corresponds to the JSON property
supportsWorkProfile. -
#type ⇒ String
The type of mobile device.
-
#unknown_sources_status ⇒ Boolean
(also: #unknown_sources_status?)
Unknown sources enabled or disabled on device (Read-only) Corresponds to the JSON property
unknownSourcesStatus. -
#user_agent ⇒ String
Gives information about the device such as
osversion. -
#wifi_mac_address ⇒ String
The device's MAC address on Wi-Fi networks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileDevice
constructor
A new instance of MobileDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileDevice
Returns a new instance of MobileDevice.
3382 3383 3384 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3382 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adb_status ⇒ Boolean Also known as: adb_status?
Adb (USB debugging) enabled or disabled on device (Read-only)
Corresponds to the JSON property adbStatus
3148 3149 3150 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3148 def adb_status @adb_status end |
#applications ⇒ Array<Google::Apis::AdminDirectoryV1::MobileDevice::Application>
The list of applications installed on an Android mobile device. It is not
applicable to Google Sync and iOS devices. The list includes any Android
applications that access Google Workspace data. When updating an applications
list, it is important to note that updates replace the existing list. If the
Android device has two existing applications and the API updates the list with
five applications, the is now the updated list of five applications.
Corresponds to the JSON property applications
3159 3160 3161 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3159 def applications @applications end |
#baseband_version ⇒ String
The device's baseband version.
Corresponds to the JSON property basebandVersion
3164 3165 3166 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3164 def baseband_version @baseband_version end |
#bootloader_version ⇒ String
Mobile Device Bootloader version (Read-only)
Corresponds to the JSON property bootloaderVersion
3169 3170 3171 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3169 def bootloader_version @bootloader_version end |
#brand ⇒ String
Mobile Device Brand (Read-only)
Corresponds to the JSON property brand
3174 3175 3176 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3174 def brand @brand end |
#build_number ⇒ String
The device's operating system build number.
Corresponds to the JSON property buildNumber
3179 3180 3181 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3179 def build_number @build_number end |
#default_language ⇒ String
The default locale used on the device.
Corresponds to the JSON property defaultLanguage
3184 3185 3186 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3184 def default_language @default_language end |
#developer_options_status ⇒ Boolean Also known as: developer_options_status?
Developer options enabled or disabled on device (Read-only)
Corresponds to the JSON property developerOptionsStatus
3189 3190 3191 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3189 def @developer_options_status end |
#device_compromised_status ⇒ String
The compromised device status.
Corresponds to the JSON property deviceCompromisedStatus
3195 3196 3197 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3195 def device_compromised_status @device_compromised_status end |
#device_id ⇒ String
The serial number for a Google Sync mobile device. For Android and iOS devices,
this is a software generated unique identifier.
Corresponds to the JSON property deviceId
3201 3202 3203 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3201 def device_id @device_id end |
#device_password_status ⇒ String
DevicePasswordStatus (Read-only)
Corresponds to the JSON property devicePasswordStatus
3206 3207 3208 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3206 def device_password_status @device_password_status end |
#email ⇒ Array<String>
The list of the owner's email addresses. If your application needs the current
list of user emails, use the get method. For additional
information, see the retrieve a user method.
Corresponds to the JSON property email
3215 3216 3217 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3215 def email @email end |
#encryption_status ⇒ String
Mobile Device Encryption Status (Read-only)
Corresponds to the JSON property encryptionStatus
3220 3221 3222 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3220 def encryption_status @encryption_status end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
3225 3226 3227 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3225 def etag @etag end |
#first_sync ⇒ DateTime
Date and time the device was first synchronized with the policy settings in
the G Suite administrator control panel (Read-only)
Corresponds to the JSON property firstSync
3231 3232 3233 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3231 def first_sync @first_sync end |
#hardware ⇒ String
Mobile Device Hardware (Read-only)
Corresponds to the JSON property hardware
3236 3237 3238 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3236 def hardware @hardware end |
#hardware_id ⇒ String
The IMEI/MEID unique identifier for Android hardware. It is not applicable to
Google Sync devices. When adding an Android mobile device, this is an optional
property. When updating one of these devices, this is a read-only property.
Corresponds to the JSON property hardwareId
3243 3244 3245 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3243 def hardware_id @hardware_id end |
#imei ⇒ String
The device's IMEI number.
Corresponds to the JSON property imei
3248 3249 3250 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3248 def imei @imei end |
#kernel_version ⇒ String
The device's kernel version.
Corresponds to the JSON property kernelVersion
3253 3254 3255 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3253 def kernel_version @kernel_version end |
#kind ⇒ String
The type of the API resource. For Mobiledevices resources, the value is admin#
directory#mobiledevice.
Corresponds to the JSON property kind
3259 3260 3261 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3259 def kind @kind end |
#last_sync ⇒ DateTime
Date and time the device was last synchronized with the policy settings in the
G Suite administrator control panel (Read-only)
Corresponds to the JSON property lastSync
3265 3266 3267 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3265 def last_sync @last_sync end |
#managed_account_is_on_owner_profile ⇒ Boolean Also known as: managed_account_is_on_owner_profile?
Boolean indicating if this account is on owner/primary profile or not.
Corresponds to the JSON property managedAccountIsOnOwnerProfile
3270 3271 3272 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3270 def managed_account_is_on_owner_profile @managed_account_is_on_owner_profile end |
#manufacturer ⇒ String
Mobile Device manufacturer (Read-only)
Corresponds to the JSON property manufacturer
3276 3277 3278 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3276 def manufacturer @manufacturer end |
#meid ⇒ String
The device's MEID number.
Corresponds to the JSON property meid
3281 3282 3283 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3281 def meid @meid end |
#model ⇒ String
The mobile device's model name, for example Nexus S. This property can be
updated. For more information, see the Developer's Guide.
Corresponds to the JSON property model
3290 3291 3292 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3290 def model @model end |
#name ⇒ Array<String>
The list of the owner's user names. If your application needs the current list
of device owner names, use the get method. For more
information about retrieving mobile device user information, see the
Developer's Guide.
Corresponds to the JSON property name
3300 3301 3302 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3300 def name @name end |
#network_operator ⇒ String
Mobile Device mobile or network operator (if available) (Read-only)
Corresponds to the JSON property networkOperator
3305 3306 3307 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3305 def network_operator @network_operator end |
#os ⇒ String
The mobile device's operating system, for example IOS 4.3 or Android 2.3.5.
This property can be updated. For more information, see
the Developer's Guide.
Corresponds to the JSON property os
3314 3315 3316 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3314 def os @os end |
#other_accounts_info ⇒ Array<String>
The list of accounts added on device (Read-only)
Corresponds to the JSON property otherAccountsInfo
3319 3320 3321 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3319 def other_accounts_info @other_accounts_info end |
#privilege ⇒ String
DMAgentPermission (Read-only)
Corresponds to the JSON property privilege
3324 3325 3326 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3324 def privilege @privilege end |
#release_version ⇒ String
Mobile Device release version version (Read-only)
Corresponds to the JSON property releaseVersion
3329 3330 3331 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3329 def release_version @release_version end |
#resource_id ⇒ String
The unique ID the API service uses to identify the mobile device.
Corresponds to the JSON property resourceId
3334 3335 3336 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3334 def resource_id @resource_id end |
#security_patch_level ⇒ Fixnum
Mobile Device Security patch level (Read-only)
Corresponds to the JSON property securityPatchLevel
3339 3340 3341 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3339 def security_patch_level @security_patch_level end |
#serial_number ⇒ String
The device's serial number.
Corresponds to the JSON property serialNumber
3344 3345 3346 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3344 def serial_number @serial_number end |
#status ⇒ String
The device's status.
Corresponds to the JSON property status
3349 3350 3351 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3349 def status @status end |
#supports_work_profile ⇒ Boolean Also known as: supports_work_profile?
Work profile supported on device (Read-only)
Corresponds to the JSON property supportsWorkProfile
3354 3355 3356 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3354 def supports_work_profile @supports_work_profile end |
#type ⇒ String
The type of mobile device.
Corresponds to the JSON property type
3360 3361 3362 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3360 def type @type end |
#unknown_sources_status ⇒ Boolean Also known as: unknown_sources_status?
Unknown sources enabled or disabled on device (Read-only)
Corresponds to the JSON property unknownSourcesStatus
3365 3366 3367 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3365 def unknown_sources_status @unknown_sources_status end |
#user_agent ⇒ String
Gives information about the device such as os version. This property can be
updated. For more information, see the Developer's Guide.
Corresponds to the JSON property userAgent
3375 3376 3377 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3375 def user_agent @user_agent end |
#wifi_mac_address ⇒ String
The device's MAC address on Wi-Fi networks.
Corresponds to the JSON property wifiMacAddress
3380 3381 3382 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3380 def wifi_mac_address @wifi_mac_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 3400 3401 3402 3403 3404 3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3387 def update!(**args) @adb_status = args[:adb_status] if args.key?(:adb_status) @applications = args[:applications] if args.key?(:applications) @baseband_version = args[:baseband_version] if args.key?(:baseband_version) @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version) @brand = args[:brand] if args.key?(:brand) @build_number = args[:build_number] if args.key?(:build_number) @default_language = args[:default_language] if args.key?(:default_language) @developer_options_status = args[:developer_options_status] if args.key?(:developer_options_status) @device_compromised_status = args[:device_compromised_status] if args.key?(:device_compromised_status) @device_id = args[:device_id] if args.key?(:device_id) @device_password_status = args[:device_password_status] if args.key?(:device_password_status) @email = args[:email] if args.key?(:email) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @etag = args[:etag] if args.key?(:etag) @first_sync = args[:first_sync] if args.key?(:first_sync) @hardware = args[:hardware] if args.key?(:hardware) @hardware_id = args[:hardware_id] if args.key?(:hardware_id) @imei = args[:imei] if args.key?(:imei) @kernel_version = args[:kernel_version] if args.key?(:kernel_version) @kind = args[:kind] if args.key?(:kind) @last_sync = args[:last_sync] if args.key?(:last_sync) @managed_account_is_on_owner_profile = args[:managed_account_is_on_owner_profile] if args.key?(:managed_account_is_on_owner_profile) @manufacturer = args[:manufacturer] if args.key?(:manufacturer) @meid = args[:meid] if args.key?(:meid) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @network_operator = args[:network_operator] if args.key?(:network_operator) @os = args[:os] if args.key?(:os) @other_accounts_info = args[:other_accounts_info] if args.key?(:other_accounts_info) @privilege = args[:privilege] if args.key?(:privilege) @release_version = args[:release_version] if args.key?(:release_version) @resource_id = args[:resource_id] if args.key?(:resource_id) @security_patch_level = args[:security_patch_level] if args.key?(:security_patch_level) @serial_number = args[:serial_number] if args.key?(:serial_number) @status = args[:status] if args.key?(:status) @supports_work_profile = args[:supports_work_profile] if args.key?(:supports_work_profile) @type = args[:type] if args.key?(:type) @unknown_sources_status = args[:unknown_sources_status] if args.key?(:unknown_sources_status) @user_agent = args[:user_agent] if args.key?(:user_agent) @wifi_mac_address = args[:wifi_mac_address] if args.key?(:wifi_mac_address) end |