Class: Google::Apis::AdminDirectoryV1::MobileDevice
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::MobileDevice
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Google Workspace Mobile Management includes Android, Google Sync, and iOS devices. For more information about common group mobile device API tasks, see the Developer's Guide.
Defined Under Namespace
Classes: Application
Instance Attribute Summary collapse
-
#adb_status ⇒ Boolean
(also: #adb_status?)
Adb (USB debugging) enabled or disabled on device (Read-only) Corresponds to the JSON property
adbStatus. -
#applications ⇒ Array<Google::Apis::AdminDirectoryV1::MobileDevice::Application>
The list of applications installed on an Android mobile device.
-
#baseband_version ⇒ String
The device's baseband version.
-
#bootloader_version ⇒ String
Mobile Device Bootloader version (Read-only) Corresponds to the JSON property
bootloaderVersion. -
#brand ⇒ String
Mobile Device Brand (Read-only) Corresponds to the JSON property
brand. -
#build_number ⇒ String
The device's operating system build number.
-
#default_language ⇒ String
The default locale used on the device.
-
#developer_options_status ⇒ Boolean
(also: #developer_options_status?)
Developer options enabled or disabled on device (Read-only) Corresponds to the JSON property
developerOptionsStatus. -
#device_compromised_status ⇒ String
The compromised device status.
-
#device_id ⇒ String
The serial number for a Google Sync mobile device.
-
#device_password_status ⇒ String
DevicePasswordStatus (Read-only) Corresponds to the JSON property
devicePasswordStatus. -
#email ⇒ Array<String>
The list of the owner's email addresses.
-
#encryption_status ⇒ String
Mobile Device Encryption Status (Read-only) Corresponds to the JSON property
encryptionStatus. -
#etag ⇒ String
ETag of the resource.
-
#first_sync ⇒ DateTime
Date and time the device was first synchronized with the policy settings in the G Suite administrator control panel (Read-only) Corresponds to the JSON property
firstSync. -
#hardware ⇒ String
Mobile Device Hardware (Read-only) Corresponds to the JSON property
hardware. -
#hardware_id ⇒ String
The IMEI/MEID unique identifier for Android hardware.
-
#imei ⇒ String
The device's IMEI number.
-
#kernel_version ⇒ String
The device's kernel version.
-
#kind ⇒ String
The type of the API resource.
-
#last_sync ⇒ DateTime
Date and time the device was last synchronized with the policy settings in the G Suite administrator control panel (Read-only) Corresponds to the JSON property
lastSync. -
#managed_account_is_on_owner_profile ⇒ Boolean
(also: #managed_account_is_on_owner_profile?)
Boolean indicating if this account is on owner/primary profile or not.
-
#manufacturer ⇒ String
Mobile Device manufacturer (Read-only) Corresponds to the JSON property
manufacturer. -
#meid ⇒ String
The device's MEID number.
-
#model ⇒ String
The mobile device's model name, for example Nexus S.
-
#name ⇒ Array<String>
The list of the owner's user names.
-
#network_operator ⇒ String
Mobile Device mobile or network operator (if available) (Read-only) Corresponds to the JSON property
networkOperator. -
#os ⇒ String
The mobile device's operating system, for example IOS 4.3 or Android 2.3.5.
-
#other_accounts_info ⇒ Array<String>
The list of accounts added on device (Read-only) Corresponds to the JSON property
otherAccountsInfo. -
#privilege ⇒ String
DMAgentPermission (Read-only) Corresponds to the JSON property
privilege. -
#release_version ⇒ String
Mobile Device release version version (Read-only) Corresponds to the JSON property
releaseVersion. -
#resource_id ⇒ String
The unique ID the API service uses to identify the mobile device.
-
#security_patch_level ⇒ Fixnum
Mobile Device Security patch level (Read-only) Corresponds to the JSON property
securityPatchLevel. -
#serial_number ⇒ String
The device's serial number.
-
#status ⇒ String
The device's status.
-
#supports_work_profile ⇒ Boolean
(also: #supports_work_profile?)
Work profile supported on device (Read-only) Corresponds to the JSON property
supportsWorkProfile. -
#type ⇒ String
The type of mobile device.
-
#unknown_sources_status ⇒ Boolean
(also: #unknown_sources_status?)
Unknown sources enabled or disabled on device (Read-only) Corresponds to the JSON property
unknownSourcesStatus. -
#user_agent ⇒ String
Gives information about the device such as
osversion. -
#wifi_mac_address ⇒ String
The device's MAC address on Wi-Fi networks.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MobileDevice
constructor
A new instance of MobileDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MobileDevice
Returns a new instance of MobileDevice.
3348 3349 3350 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3348 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adb_status ⇒ Boolean Also known as: adb_status?
Adb (USB debugging) enabled or disabled on device (Read-only)
Corresponds to the JSON property adbStatus
3114 3115 3116 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3114 def adb_status @adb_status end |
#applications ⇒ Array<Google::Apis::AdminDirectoryV1::MobileDevice::Application>
The list of applications installed on an Android mobile device. It is not
applicable to Google Sync and iOS devices. The list includes any Android
applications that access Google Workspace data. When updating an applications
list, it is important to note that updates replace the existing list. If the
Android device has two existing applications and the API updates the list with
five applications, the is now the updated list of five applications.
Corresponds to the JSON property applications
3125 3126 3127 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3125 def applications @applications end |
#baseband_version ⇒ String
The device's baseband version.
Corresponds to the JSON property basebandVersion
3130 3131 3132 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3130 def baseband_version @baseband_version end |
#bootloader_version ⇒ String
Mobile Device Bootloader version (Read-only)
Corresponds to the JSON property bootloaderVersion
3135 3136 3137 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3135 def bootloader_version @bootloader_version end |
#brand ⇒ String
Mobile Device Brand (Read-only)
Corresponds to the JSON property brand
3140 3141 3142 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3140 def brand @brand end |
#build_number ⇒ String
The device's operating system build number.
Corresponds to the JSON property buildNumber
3145 3146 3147 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3145 def build_number @build_number end |
#default_language ⇒ String
The default locale used on the device.
Corresponds to the JSON property defaultLanguage
3150 3151 3152 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3150 def default_language @default_language end |
#developer_options_status ⇒ Boolean Also known as: developer_options_status?
Developer options enabled or disabled on device (Read-only)
Corresponds to the JSON property developerOptionsStatus
3155 3156 3157 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3155 def @developer_options_status end |
#device_compromised_status ⇒ String
The compromised device status.
Corresponds to the JSON property deviceCompromisedStatus
3161 3162 3163 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3161 def device_compromised_status @device_compromised_status end |
#device_id ⇒ String
The serial number for a Google Sync mobile device. For Android and iOS devices,
this is a software generated unique identifier.
Corresponds to the JSON property deviceId
3167 3168 3169 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3167 def device_id @device_id end |
#device_password_status ⇒ String
DevicePasswordStatus (Read-only)
Corresponds to the JSON property devicePasswordStatus
3172 3173 3174 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3172 def device_password_status @device_password_status end |
#email ⇒ Array<String>
The list of the owner's email addresses. If your application needs the current
list of user emails, use the get method. For additional
information, see the retrieve a user method.
Corresponds to the JSON property email
3181 3182 3183 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3181 def email @email end |
#encryption_status ⇒ String
Mobile Device Encryption Status (Read-only)
Corresponds to the JSON property encryptionStatus
3186 3187 3188 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3186 def encryption_status @encryption_status end |
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
3191 3192 3193 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3191 def etag @etag end |
#first_sync ⇒ DateTime
Date and time the device was first synchronized with the policy settings in
the G Suite administrator control panel (Read-only)
Corresponds to the JSON property firstSync
3197 3198 3199 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3197 def first_sync @first_sync end |
#hardware ⇒ String
Mobile Device Hardware (Read-only)
Corresponds to the JSON property hardware
3202 3203 3204 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3202 def hardware @hardware end |
#hardware_id ⇒ String
The IMEI/MEID unique identifier for Android hardware. It is not applicable to
Google Sync devices. When adding an Android mobile device, this is an optional
property. When updating one of these devices, this is a read-only property.
Corresponds to the JSON property hardwareId
3209 3210 3211 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3209 def hardware_id @hardware_id end |
#imei ⇒ String
The device's IMEI number.
Corresponds to the JSON property imei
3214 3215 3216 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3214 def imei @imei end |
#kernel_version ⇒ String
The device's kernel version.
Corresponds to the JSON property kernelVersion
3219 3220 3221 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3219 def kernel_version @kernel_version end |
#kind ⇒ String
The type of the API resource. For Mobiledevices resources, the value is admin#
directory#mobiledevice.
Corresponds to the JSON property kind
3225 3226 3227 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3225 def kind @kind end |
#last_sync ⇒ DateTime
Date and time the device was last synchronized with the policy settings in the
G Suite administrator control panel (Read-only)
Corresponds to the JSON property lastSync
3231 3232 3233 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3231 def last_sync @last_sync end |
#managed_account_is_on_owner_profile ⇒ Boolean Also known as: managed_account_is_on_owner_profile?
Boolean indicating if this account is on owner/primary profile or not.
Corresponds to the JSON property managedAccountIsOnOwnerProfile
3236 3237 3238 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3236 def managed_account_is_on_owner_profile @managed_account_is_on_owner_profile end |
#manufacturer ⇒ String
Mobile Device manufacturer (Read-only)
Corresponds to the JSON property manufacturer
3242 3243 3244 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3242 def manufacturer @manufacturer end |
#meid ⇒ String
The device's MEID number.
Corresponds to the JSON property meid
3247 3248 3249 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3247 def meid @meid end |
#model ⇒ String
The mobile device's model name, for example Nexus S. This property can be
updated. For more information, see the Developer's Guide.
Corresponds to the JSON property model
3256 3257 3258 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3256 def model @model end |
#name ⇒ Array<String>
The list of the owner's user names. If your application needs the current list
of device owner names, use the get method. For more
information about retrieving mobile device user information, see the
Developer's Guide.
Corresponds to the JSON property name
3266 3267 3268 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3266 def name @name end |
#network_operator ⇒ String
Mobile Device mobile or network operator (if available) (Read-only)
Corresponds to the JSON property networkOperator
3271 3272 3273 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3271 def network_operator @network_operator end |
#os ⇒ String
The mobile device's operating system, for example IOS 4.3 or Android 2.3.5.
This property can be updated. For more information, see
the Developer's Guide.
Corresponds to the JSON property os
3280 3281 3282 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3280 def os @os end |
#other_accounts_info ⇒ Array<String>
The list of accounts added on device (Read-only)
Corresponds to the JSON property otherAccountsInfo
3285 3286 3287 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3285 def other_accounts_info @other_accounts_info end |
#privilege ⇒ String
DMAgentPermission (Read-only)
Corresponds to the JSON property privilege
3290 3291 3292 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3290 def privilege @privilege end |
#release_version ⇒ String
Mobile Device release version version (Read-only)
Corresponds to the JSON property releaseVersion
3295 3296 3297 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3295 def release_version @release_version end |
#resource_id ⇒ String
The unique ID the API service uses to identify the mobile device.
Corresponds to the JSON property resourceId
3300 3301 3302 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3300 def resource_id @resource_id end |
#security_patch_level ⇒ Fixnum
Mobile Device Security patch level (Read-only)
Corresponds to the JSON property securityPatchLevel
3305 3306 3307 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3305 def security_patch_level @security_patch_level end |
#serial_number ⇒ String
The device's serial number.
Corresponds to the JSON property serialNumber
3310 3311 3312 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3310 def serial_number @serial_number end |
#status ⇒ String
The device's status.
Corresponds to the JSON property status
3315 3316 3317 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3315 def status @status end |
#supports_work_profile ⇒ Boolean Also known as: supports_work_profile?
Work profile supported on device (Read-only)
Corresponds to the JSON property supportsWorkProfile
3320 3321 3322 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3320 def supports_work_profile @supports_work_profile end |
#type ⇒ String
The type of mobile device.
Corresponds to the JSON property type
3326 3327 3328 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3326 def type @type end |
#unknown_sources_status ⇒ Boolean Also known as: unknown_sources_status?
Unknown sources enabled or disabled on device (Read-only)
Corresponds to the JSON property unknownSourcesStatus
3331 3332 3333 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3331 def unknown_sources_status @unknown_sources_status end |
#user_agent ⇒ String
Gives information about the device such as os version. This property can be
updated. For more information, see the Developer's Guide.
Corresponds to the JSON property userAgent
3341 3342 3343 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3341 def user_agent @user_agent end |
#wifi_mac_address ⇒ String
The device's MAC address on Wi-Fi networks.
Corresponds to the JSON property wifiMacAddress
3346 3347 3348 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3346 def wifi_mac_address @wifi_mac_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3353 3354 3355 3356 3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 3367 3368 3369 3370 3371 3372 3373 3374 3375 3376 3377 3378 3379 3380 3381 3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3353 def update!(**args) @adb_status = args[:adb_status] if args.key?(:adb_status) @applications = args[:applications] if args.key?(:applications) @baseband_version = args[:baseband_version] if args.key?(:baseband_version) @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version) @brand = args[:brand] if args.key?(:brand) @build_number = args[:build_number] if args.key?(:build_number) @default_language = args[:default_language] if args.key?(:default_language) @developer_options_status = args[:developer_options_status] if args.key?(:developer_options_status) @device_compromised_status = args[:device_compromised_status] if args.key?(:device_compromised_status) @device_id = args[:device_id] if args.key?(:device_id) @device_password_status = args[:device_password_status] if args.key?(:device_password_status) @email = args[:email] if args.key?(:email) @encryption_status = args[:encryption_status] if args.key?(:encryption_status) @etag = args[:etag] if args.key?(:etag) @first_sync = args[:first_sync] if args.key?(:first_sync) @hardware = args[:hardware] if args.key?(:hardware) @hardware_id = args[:hardware_id] if args.key?(:hardware_id) @imei = args[:imei] if args.key?(:imei) @kernel_version = args[:kernel_version] if args.key?(:kernel_version) @kind = args[:kind] if args.key?(:kind) @last_sync = args[:last_sync] if args.key?(:last_sync) @managed_account_is_on_owner_profile = args[:managed_account_is_on_owner_profile] if args.key?(:managed_account_is_on_owner_profile) @manufacturer = args[:manufacturer] if args.key?(:manufacturer) @meid = args[:meid] if args.key?(:meid) @model = args[:model] if args.key?(:model) @name = args[:name] if args.key?(:name) @network_operator = args[:network_operator] if args.key?(:network_operator) @os = args[:os] if args.key?(:os) @other_accounts_info = args[:other_accounts_info] if args.key?(:other_accounts_info) @privilege = args[:privilege] if args.key?(:privilege) @release_version = args[:release_version] if args.key?(:release_version) @resource_id = args[:resource_id] if args.key?(:resource_id) @security_patch_level = args[:security_patch_level] if args.key?(:security_patch_level) @serial_number = args[:serial_number] if args.key?(:serial_number) @status = args[:status] if args.key?(:status) @supports_work_profile = args[:supports_work_profile] if args.key?(:supports_work_profile) @type = args[:type] if args.key?(:type) @unknown_sources_status = args[:unknown_sources_status] if args.key?(:unknown_sources_status) @user_agent = args[:user_agent] if args.key?(:user_agent) @wifi_mac_address = args[:wifi_mac_address] if args.key?(:wifi_mac_address) end |