Class: Google::Apis::AdminDirectoryV1::MobileDevice

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Google Workspace Mobile Management includes Android, Google Sync, and iOS devices. For more information about common group mobile device API tasks, see the Developer's Guide.

Defined Under Namespace

Classes: Application

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileDevice

Returns a new instance of MobileDevice.



3346
3347
3348
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adb_statusBoolean Also known as: adb_status?

Adb (USB debugging) enabled or disabled on device (Read-only) Corresponds to the JSON property adbStatus

Returns:

  • (Boolean)


3112
3113
3114
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3112

def adb_status
  @adb_status
end

#applicationsArray<Google::Apis::AdminDirectoryV1::MobileDevice::Application>

The list of applications installed on an Android mobile device. It is not applicable to Google Sync and iOS devices. The list includes any Android applications that access Google Workspace data. When updating an applications list, it is important to note that updates replace the existing list. If the Android device has two existing applications and the API updates the list with five applications, the is now the updated list of five applications. Corresponds to the JSON property applications



3123
3124
3125
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3123

def applications
  @applications
end

#baseband_versionString

The device's baseband version. Corresponds to the JSON property basebandVersion

Returns:

  • (String)


3128
3129
3130
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3128

def baseband_version
  @baseband_version
end

#bootloader_versionString

Mobile Device Bootloader version (Read-only) Corresponds to the JSON property bootloaderVersion

Returns:

  • (String)


3133
3134
3135
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3133

def bootloader_version
  @bootloader_version
end

#brandString

Mobile Device Brand (Read-only) Corresponds to the JSON property brand

Returns:

  • (String)


3138
3139
3140
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3138

def brand
  @brand
end

#build_numberString

The device's operating system build number. Corresponds to the JSON property buildNumber

Returns:

  • (String)


3143
3144
3145
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3143

def build_number
  @build_number
end

#default_languageString

The default locale used on the device. Corresponds to the JSON property defaultLanguage

Returns:

  • (String)


3148
3149
3150
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3148

def default_language
  @default_language
end

#developer_options_statusBoolean Also known as: developer_options_status?

Developer options enabled or disabled on device (Read-only) Corresponds to the JSON property developerOptionsStatus

Returns:

  • (Boolean)


3153
3154
3155
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3153

def developer_options_status
  @developer_options_status
end

#device_compromised_statusString

The compromised device status. Corresponds to the JSON property deviceCompromisedStatus

Returns:

  • (String)


3159
3160
3161
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3159

def device_compromised_status
  @device_compromised_status
end

#device_idString

The serial number for a Google Sync mobile device. For Android and iOS devices, this is a software generated unique identifier. Corresponds to the JSON property deviceId

Returns:

  • (String)


3165
3166
3167
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3165

def device_id
  @device_id
end

#device_password_statusString

DevicePasswordStatus (Read-only) Corresponds to the JSON property devicePasswordStatus

Returns:

  • (String)


3170
3171
3172
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3170

def device_password_status
  @device_password_status
end

#emailArray<String>

The list of the owner's email addresses. If your application needs the current list of user emails, use the get method. For additional information, see the retrieve a user method. Corresponds to the JSON property email

Returns:

  • (Array<String>)


3179
3180
3181
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3179

def email
  @email
end

#encryption_statusString

Mobile Device Encryption Status (Read-only) Corresponds to the JSON property encryptionStatus

Returns:

  • (String)


3184
3185
3186
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3184

def encryption_status
  @encryption_status
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


3189
3190
3191
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3189

def etag
  @etag
end

#first_syncDateTime

Date and time the device was first synchronized with the policy settings in the G Suite administrator control panel (Read-only) Corresponds to the JSON property firstSync

Returns:

  • (DateTime)


3195
3196
3197
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3195

def first_sync
  @first_sync
end

#hardwareString

Mobile Device Hardware (Read-only) Corresponds to the JSON property hardware

Returns:

  • (String)


3200
3201
3202
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3200

def hardware
  @hardware
end

#hardware_idString

The IMEI/MEID unique identifier for Android hardware. It is not applicable to Google Sync devices. When adding an Android mobile device, this is an optional property. When updating one of these devices, this is a read-only property. Corresponds to the JSON property hardwareId

Returns:

  • (String)


3207
3208
3209
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3207

def hardware_id
  @hardware_id
end

#imeiString

The device's IMEI number. Corresponds to the JSON property imei

Returns:

  • (String)


3212
3213
3214
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3212

def imei
  @imei
end

#kernel_versionString

The device's kernel version. Corresponds to the JSON property kernelVersion

Returns:

  • (String)


3217
3218
3219
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3217

def kernel_version
  @kernel_version
end

#kindString

The type of the API resource. For Mobiledevices resources, the value is admin# directory#mobiledevice. Corresponds to the JSON property kind

Returns:

  • (String)


3223
3224
3225
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3223

def kind
  @kind
end

#last_syncDateTime

Date and time the device was last synchronized with the policy settings in the G Suite administrator control panel (Read-only) Corresponds to the JSON property lastSync

Returns:

  • (DateTime)


3229
3230
3231
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3229

def last_sync
  @last_sync
end

#managed_account_is_on_owner_profileBoolean Also known as: managed_account_is_on_owner_profile?

Boolean indicating if this account is on owner/primary profile or not. Corresponds to the JSON property managedAccountIsOnOwnerProfile

Returns:

  • (Boolean)


3234
3235
3236
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3234

def 
  @managed_account_is_on_owner_profile
end

#manufacturerString

Mobile Device manufacturer (Read-only) Corresponds to the JSON property manufacturer

Returns:

  • (String)


3240
3241
3242
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3240

def manufacturer
  @manufacturer
end

#meidString

The device's MEID number. Corresponds to the JSON property meid

Returns:

  • (String)


3245
3246
3247
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3245

def meid
  @meid
end

#modelString

The mobile device's model name, for example Nexus S. This property can be updated. For more information, see the Developer's Guide. Corresponds to the JSON property model

Returns:

  • (String)


3254
3255
3256
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3254

def model
  @model
end

#nameArray<String>

The list of the owner's user names. If your application needs the current list of device owner names, use the get method. For more information about retrieving mobile device user information, see the Developer's Guide. Corresponds to the JSON property name

Returns:

  • (Array<String>)


3264
3265
3266
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3264

def name
  @name
end

#network_operatorString

Mobile Device mobile or network operator (if available) (Read-only) Corresponds to the JSON property networkOperator

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3269

def network_operator
  @network_operator
end

#osString

The mobile device's operating system, for example IOS 4.3 or Android 2.3.5. This property can be updated. For more information, see the Developer's Guide. Corresponds to the JSON property os

Returns:

  • (String)


3278
3279
3280
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3278

def os
  @os
end

#other_accounts_infoArray<String>

The list of accounts added on device (Read-only) Corresponds to the JSON property otherAccountsInfo

Returns:

  • (Array<String>)


3283
3284
3285
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3283

def other_accounts_info
  @other_accounts_info
end

#privilegeString

DMAgentPermission (Read-only) Corresponds to the JSON property privilege

Returns:

  • (String)


3288
3289
3290
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3288

def privilege
  @privilege
end

#release_versionString

Mobile Device release version version (Read-only) Corresponds to the JSON property releaseVersion

Returns:

  • (String)


3293
3294
3295
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3293

def release_version
  @release_version
end

#resource_idString

The unique ID the API service uses to identify the mobile device. Corresponds to the JSON property resourceId

Returns:

  • (String)


3298
3299
3300
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3298

def resource_id
  @resource_id
end

#security_patch_levelFixnum

Mobile Device Security patch level (Read-only) Corresponds to the JSON property securityPatchLevel

Returns:

  • (Fixnum)


3303
3304
3305
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3303

def security_patch_level
  @security_patch_level
end

#serial_numberString

The device's serial number. Corresponds to the JSON property serialNumber

Returns:

  • (String)


3308
3309
3310
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3308

def serial_number
  @serial_number
end

#statusString

The device's status. Corresponds to the JSON property status

Returns:

  • (String)


3313
3314
3315
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3313

def status
  @status
end

#supports_work_profileBoolean Also known as: supports_work_profile?

Work profile supported on device (Read-only) Corresponds to the JSON property supportsWorkProfile

Returns:

  • (Boolean)


3318
3319
3320
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3318

def supports_work_profile
  @supports_work_profile
end

#typeString

The type of mobile device. Corresponds to the JSON property type

Returns:

  • (String)


3324
3325
3326
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3324

def type
  @type
end

#unknown_sources_statusBoolean Also known as: unknown_sources_status?

Unknown sources enabled or disabled on device (Read-only) Corresponds to the JSON property unknownSourcesStatus

Returns:

  • (Boolean)


3329
3330
3331
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3329

def unknown_sources_status
  @unknown_sources_status
end

#user_agentString

Gives information about the device such as os version. This property can be updated. For more information, see the Developer's Guide. Corresponds to the JSON property userAgent

Returns:

  • (String)


3339
3340
3341
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3339

def user_agent
  @user_agent
end

#wifi_mac_addressString

The device's MAC address on Wi-Fi networks. Corresponds to the JSON property wifiMacAddress

Returns:

  • (String)


3344
3345
3346
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3344

def wifi_mac_address
  @wifi_mac_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3351
3352
3353
3354
3355
3356
3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
3374
3375
3376
3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3351

def update!(**args)
  @adb_status = args[:adb_status] if args.key?(:adb_status)
  @applications = args[:applications] if args.key?(:applications)
  @baseband_version = args[:baseband_version] if args.key?(:baseband_version)
  @bootloader_version = args[:bootloader_version] if args.key?(:bootloader_version)
  @brand = args[:brand] if args.key?(:brand)
  @build_number = args[:build_number] if args.key?(:build_number)
  @default_language = args[:default_language] if args.key?(:default_language)
  @developer_options_status = args[:developer_options_status] if args.key?(:developer_options_status)
  @device_compromised_status = args[:device_compromised_status] if args.key?(:device_compromised_status)
  @device_id = args[:device_id] if args.key?(:device_id)
  @device_password_status = args[:device_password_status] if args.key?(:device_password_status)
  @email = args[:email] if args.key?(:email)
  @encryption_status = args[:encryption_status] if args.key?(:encryption_status)
  @etag = args[:etag] if args.key?(:etag)
  @first_sync = args[:first_sync] if args.key?(:first_sync)
  @hardware = args[:hardware] if args.key?(:hardware)
  @hardware_id = args[:hardware_id] if args.key?(:hardware_id)
  @imei = args[:imei] if args.key?(:imei)
  @kernel_version = args[:kernel_version] if args.key?(:kernel_version)
  @kind = args[:kind] if args.key?(:kind)
  @last_sync = args[:last_sync] if args.key?(:last_sync)
  @managed_account_is_on_owner_profile = args[:managed_account_is_on_owner_profile] if args.key?(:managed_account_is_on_owner_profile)
  @manufacturer = args[:manufacturer] if args.key?(:manufacturer)
  @meid = args[:meid] if args.key?(:meid)
  @model = args[:model] if args.key?(:model)
  @name = args[:name] if args.key?(:name)
  @network_operator = args[:network_operator] if args.key?(:network_operator)
  @os = args[:os] if args.key?(:os)
  @other_accounts_info = args[:other_accounts_info] if args.key?(:other_accounts_info)
  @privilege = args[:privilege] if args.key?(:privilege)
  @release_version = args[:release_version] if args.key?(:release_version)
  @resource_id = args[:resource_id] if args.key?(:resource_id)
  @security_patch_level = args[:security_patch_level] if args.key?(:security_patch_level)
  @serial_number = args[:serial_number] if args.key?(:serial_number)
  @status = args[:status] if args.key?(:status)
  @supports_work_profile = args[:supports_work_profile] if args.key?(:supports_work_profile)
  @type = args[:type] if args.key?(:type)
  @unknown_sources_status = args[:unknown_sources_status] if args.key?(:unknown_sources_status)
  @user_agent = args[:user_agent] if args.key?(:user_agent)
  @wifi_mac_address = args[:wifi_mac_address] if args.key?(:wifi_mac_address)
end