Class: Google::Apis::AdminDirectoryV1::OrgUnit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Managing your account's organizational units allows you to configure your users' access to services and custom settings. For more information about common organizational unit tasks, see the Developer's Guide. The customer's organizational unit hierarchy is limited to 35 levels of depth.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrgUnit

Returns a new instance of OrgUnit.



3607
3608
3609
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#block_inheritanceBoolean Also known as: block_inheritance?

This field is deprecated and setting its value has no effect. Corresponds to the JSON property blockInheritance

Returns:

  • (Boolean)


3546
3547
3548
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3546

def block_inheritance
  @block_inheritance
end

#descriptionString

Description of the organizational unit. Corresponds to the JSON property description

Returns:

  • (String)


3552
3553
3554
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3552

def description
  @description
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


3557
3558
3559
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3557

def etag
  @etag
end

#kindString

The type of the API resource. For Orgunits resources, the value is admin# directory#orgUnit. Corresponds to the JSON property kind

Returns:

  • (String)


3563
3564
3565
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3563

def kind
  @kind
end

#nameString

The organizational unit's path name. For example, an organizational unit's name within the /corp/support/sales_support parent path is sales_support. Required. Corresponds to the JSON property name

Returns:

  • (String)


3570
3571
3572
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3570

def name
  @name
end

#org_unit_idString

The unique ID of the organizational unit. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


3575
3576
3577
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3575

def org_unit_id
  @org_unit_id
end

#org_unit_pathString

The full path to the organizational unit. The orgUnitPath is a derived property. When listed, it is derived from parentOrgunitPath and organizational unit's name. For example, for an organizational unit named ' apps' under parent organization '/engineering', the orgUnitPath is '/ engineering/apps'. In order to edit an orgUnitPath, either update the name of the organization or the parentOrgunitPath. A user's organizational unit determines which Google Workspace services the user has access to. If the user is moved to a new organization, the user's access changes. For more information about organization structures, see the administration help center. For more information about moving a user to a different organization, see Update a user. Corresponds to the JSON property orgUnitPath

Returns:

  • (String)


3592
3593
3594
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3592

def org_unit_path
  @org_unit_path
end

#parent_org_unit_idString

The unique ID of the parent organizational unit. Required, unless parentOrgUnitPath is set. Corresponds to the JSON property parentOrgUnitId

Returns:

  • (String)


3598
3599
3600
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3598

def parent_org_unit_id
  @parent_org_unit_id
end

#parent_org_unit_pathString

The organizational unit's parent path. For example, /corp/sales is the parent path for /corp/sales/sales_support organizational unit. Required, unless parentOrgUnitId is set. Corresponds to the JSON property parentOrgUnitPath

Returns:

  • (String)


3605
3606
3607
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3605

def parent_org_unit_path
  @parent_org_unit_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3612

def update!(**args)
  @block_inheritance = args[:block_inheritance] if args.key?(:block_inheritance)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @org_unit_path = args[:org_unit_path] if args.key?(:org_unit_path)
  @parent_org_unit_id = args[:parent_org_unit_id] if args.key?(:parent_org_unit_id)
  @parent_org_unit_path = args[:parent_org_unit_path] if args.key?(:parent_org_unit_path)
end