Class: Google::Apis::AdminDirectoryV1::OrgUnit

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Managing your account's organizational units allows you to configure your users' access to services and custom settings. For more information about common organizational unit tasks, see the Developer's Guide. The customer's organizational unit hierarchy is limited to 35 levels of depth.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrgUnit

Returns a new instance of OrgUnit.



3573
3574
3575
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#block_inheritanceBoolean Also known as: block_inheritance?

This field is deprecated and setting its value has no effect. Corresponds to the JSON property blockInheritance

Returns:

  • (Boolean)


3512
3513
3514
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3512

def block_inheritance
  @block_inheritance
end

#descriptionString

Description of the organizational unit. Corresponds to the JSON property description

Returns:

  • (String)


3518
3519
3520
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3518

def description
  @description
end

#etagString

ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


3523
3524
3525
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3523

def etag
  @etag
end

#kindString

The type of the API resource. For Orgunits resources, the value is admin# directory#orgUnit. Corresponds to the JSON property kind

Returns:

  • (String)


3529
3530
3531
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3529

def kind
  @kind
end

#nameString

The organizational unit's path name. For example, an organizational unit's name within the /corp/support/sales_support parent path is sales_support. Required. Corresponds to the JSON property name

Returns:

  • (String)


3536
3537
3538
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3536

def name
  @name
end

#org_unit_idString

The unique ID of the organizational unit. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


3541
3542
3543
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3541

def org_unit_id
  @org_unit_id
end

#org_unit_pathString

The full path to the organizational unit. The orgUnitPath is a derived property. When listed, it is derived from parentOrgunitPath and organizational unit's name. For example, for an organizational unit named ' apps' under parent organization '/engineering', the orgUnitPath is '/ engineering/apps'. In order to edit an orgUnitPath, either update the name of the organization or the parentOrgunitPath. A user's organizational unit determines which Google Workspace services the user has access to. If the user is moved to a new organization, the user's access changes. For more information about organization structures, see the administration help center. For more information about moving a user to a different organization, see Update a user. Corresponds to the JSON property orgUnitPath

Returns:

  • (String)


3558
3559
3560
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3558

def org_unit_path
  @org_unit_path
end

#parent_org_unit_idString

The unique ID of the parent organizational unit. Required, unless parentOrgUnitPath is set. Corresponds to the JSON property parentOrgUnitId

Returns:

  • (String)


3564
3565
3566
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3564

def parent_org_unit_id
  @parent_org_unit_id
end

#parent_org_unit_pathString

The organizational unit's parent path. For example, /corp/sales is the parent path for /corp/sales/sales_support organizational unit. Required, unless parentOrgUnitId is set. Corresponds to the JSON property parentOrgUnitPath

Returns:

  • (String)


3571
3572
3573
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3571

def parent_org_unit_path
  @parent_org_unit_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3578
3579
3580
3581
3582
3583
3584
3585
3586
3587
3588
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3578

def update!(**args)
  @block_inheritance = args[:block_inheritance] if args.key?(:block_inheritance)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @org_unit_path = args[:org_unit_path] if args.key?(:org_unit_path)
  @parent_org_unit_id = args[:parent_org_unit_id] if args.key?(:parent_org_unit_id)
  @parent_org_unit_path = args[:parent_org_unit_path] if args.key?(:parent_org_unit_path)
end