Class: Google::Apis::AdminDirectoryV1::PrintServer

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

Configuration for a print server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrintServer

Returns a new instance of PrintServer.



3720
3721
3722
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the print server was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3683
3684
3685
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3683

def create_time
  @create_time
end

#descriptionString

Editable. Description of the print server (as shown in the Admin console). Corresponds to the JSON property description

Returns:

  • (String)


3688
3689
3690
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3688

def description
  @description
end

#display_nameString

Editable. Display name of the print server (as shown in the Admin console). Corresponds to the JSON property displayName

Returns:

  • (String)


3693
3694
3695
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3693

def display_name
  @display_name
end

#idString

Immutable. ID of the print server. Leave empty when creating. Corresponds to the JSON property id

Returns:

  • (String)


3698
3699
3700
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3698

def id
  @id
end

#nameString

Identifier. Resource name of the print server. Leave empty when creating. Format: customers/customer.id/printServers/print_server.id` Corresponds to the JSON propertyname`

Returns:

  • (String)


3704
3705
3706
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3704

def name
  @name
end

#org_unit_idString

ID of the organization unit (OU) that owns this print server. This value can only be set when the print server is initially created. If it's not populated, the print server is placed under the root OU. The org_unit_id can be retrieved using the Directory API. Corresponds to the JSON property orgUnitId

Returns:

  • (String)


3713
3714
3715
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3713

def org_unit_id
  @org_unit_id
end

#uriString

Editable. Print server URI. Corresponds to the JSON property uri

Returns:

  • (String)


3718
3719
3720
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3718

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3725
3726
3727
3728
3729
3730
3731
3732
3733
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3725

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @id = args[:id] if args.key?(:id)
  @name = args[:name] if args.key?(:name)
  @org_unit_id = args[:org_unit_id] if args.key?(:org_unit_id)
  @uri = args[:uri] if args.key?(:uri)
end