Class: Google::Apis::AdminDirectoryV1::PrintServerFailureInfo
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::PrintServerFailureInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Info about failures
Instance Attribute Summary collapse
-
#error_code ⇒ String
Canonical code for why the update failed to apply.
-
#error_message ⇒ String
Failure reason message.
-
#print_server ⇒ Google::Apis::AdminDirectoryV1::PrintServer
Configuration for a print server.
-
#print_server_id ⇒ String
ID of a failed print server.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PrintServerFailureInfo
constructor
A new instance of PrintServerFailureInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PrintServerFailureInfo
Returns a new instance of PrintServerFailureInfo.
3758 3759 3760 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3758 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_code ⇒ String
Canonical code for why the update failed to apply.
Corresponds to the JSON property errorCode
3741 3742 3743 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3741 def error_code @error_code end |
#error_message ⇒ String
Failure reason message.
Corresponds to the JSON property errorMessage
3746 3747 3748 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3746 def @error_message end |
#print_server ⇒ Google::Apis::AdminDirectoryV1::PrintServer
Configuration for a print server.
Corresponds to the JSON property printServer
3751 3752 3753 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3751 def print_server @print_server end |
#print_server_id ⇒ String
ID of a failed print server.
Corresponds to the JSON property printServerId
3756 3757 3758 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3756 def print_server_id @print_server_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3763 3764 3765 3766 3767 3768 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3763 def update!(**args) @error_code = args[:error_code] if args.key?(:error_code) @error_message = args[:error_message] if args.key?(:error_message) @print_server = args[:print_server] if args.key?(:print_server) @print_server_id = args[:print_server_id] if args.key?(:print_server_id) end |