Class: Google::Apis::AdminDirectoryV1::Role
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::Role
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Defined Under Namespace
Classes: RolePrivilege
Instance Attribute Summary collapse
-
#etag ⇒ String
ETag of the resource.
-
#is_super_admin_role ⇒ Boolean
(also: #is_super_admin_role?)
Returns
trueif the role is a super admin role. -
#is_system_role ⇒ Boolean
(also: #is_system_role?)
Returns
trueif this is a pre-defined system role. -
#kind ⇒ String
The type of the API resource.
-
#role_description ⇒ String
A short description of the role.
-
#role_id ⇒ Fixnum
ID of the role.
-
#role_name ⇒ String
Name of the role.
-
#role_privileges ⇒ Array<Google::Apis::AdminDirectoryV1::Role::RolePrivilege>
The set of privileges that are granted to this role.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Role
constructor
A new instance of Role.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Role
Returns a new instance of Role.
4021 4022 4023 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
3982 3983 3984 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3982 def etag @etag end |
#is_super_admin_role ⇒ Boolean Also known as: is_super_admin_role?
Returns true if the role is a super admin role.
Corresponds to the JSON property isSuperAdminRole
3987 3988 3989 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3987 def is_super_admin_role @is_super_admin_role end |
#is_system_role ⇒ Boolean Also known as: is_system_role?
Returns true if this is a pre-defined system role.
Corresponds to the JSON property isSystemRole
3993 3994 3995 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3993 def is_system_role @is_system_role end |
#kind ⇒ String
The type of the API resource. This is always admin#directory#role.
Corresponds to the JSON property kind
3999 4000 4001 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 3999 def kind @kind end |
#role_description ⇒ String
A short description of the role.
Corresponds to the JSON property roleDescription
4004 4005 4006 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4004 def role_description @role_description end |
#role_id ⇒ Fixnum
ID of the role.
Corresponds to the JSON property roleId
4009 4010 4011 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4009 def role_id @role_id end |
#role_name ⇒ String
Name of the role.
Corresponds to the JSON property roleName
4014 4015 4016 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4014 def role_name @role_name end |
#role_privileges ⇒ Array<Google::Apis::AdminDirectoryV1::Role::RolePrivilege>
The set of privileges that are granted to this role.
Corresponds to the JSON property rolePrivileges
4019 4020 4021 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4019 def role_privileges @role_privileges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4026 def update!(**args) @etag = args[:etag] if args.key?(:etag) @is_super_admin_role = args[:is_super_admin_role] if args.key?(:is_super_admin_role) @is_system_role = args[:is_system_role] if args.key?(:is_system_role) @kind = args[:kind] if args.key?(:kind) @role_description = args[:role_description] if args.key?(:role_description) @role_id = args[:role_id] if args.key?(:role_id) @role_name = args[:role_name] if args.key?(:role_name) @role_privileges = args[:role_privileges] if args.key?(:role_privileges) end |