Class: Google::Apis::AdminDirectoryV1::SchemaFieldSpec::NumericIndexingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::SchemaFieldSpec::NumericIndexingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Indexing spec for a numeric field. By default, only exact match queries will
be supported for numeric fields. Setting the numericIndexingSpec allows
range queries to be supported.
Instance Attribute Summary collapse
-
#max_value ⇒ Float
Maximum value of this field.
-
#min_value ⇒ Float
Minimum value of this field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NumericIndexingSpec
constructor
A new instance of NumericIndexingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NumericIndexingSpec
Returns a new instance of NumericIndexingSpec.
4423 4424 4425 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4423 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Float
Maximum value of this field. This is meant to be indicative rather than
enforced. Values outside this range will still be indexed, but search may not
be as performant.
Corresponds to the JSON property maxValue
4414 4415 4416 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4414 def max_value @max_value end |
#min_value ⇒ Float
Minimum value of this field. This is meant to be indicative rather than
enforced. Values outside this range will still be indexed, but search may not
be as performant.
Corresponds to the JSON property minValue
4421 4422 4423 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4421 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4428 4429 4430 4431 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4428 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |