Class: Google::Apis::AdminDirectoryV1::SchemaFieldSpec::NumericIndexingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::SchemaFieldSpec::NumericIndexingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Indexing spec for a numeric field. By default, only exact match queries will
be supported for numeric fields. Setting the numericIndexingSpec allows
range queries to be supported.
Instance Attribute Summary collapse
-
#max_value ⇒ Float
Maximum value of this field.
-
#min_value ⇒ Float
Minimum value of this field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NumericIndexingSpec
constructor
A new instance of NumericIndexingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NumericIndexingSpec
Returns a new instance of NumericIndexingSpec.
4389 4390 4391 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Float
Maximum value of this field. This is meant to be indicative rather than
enforced. Values outside this range will still be indexed, but search may not
be as performant.
Corresponds to the JSON property maxValue
4380 4381 4382 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4380 def max_value @max_value end |
#min_value ⇒ Float
Minimum value of this field. This is meant to be indicative rather than
enforced. Values outside this range will still be indexed, but search may not
be as performant.
Corresponds to the JSON property minValue
4387 4388 4389 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4387 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4394 4395 4396 4397 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4394 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |