Class: Google::Apis::AdminDirectoryV1::SchemaFieldSpec::NumericIndexingSpec
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::SchemaFieldSpec::NumericIndexingSpec
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
Indexing spec for a numeric field. By default, only exact match queries will
be supported for numeric fields. Setting the numericIndexingSpec allows
range queries to be supported.
Instance Attribute Summary collapse
-
#max_value ⇒ Float
Maximum value of this field.
-
#min_value ⇒ Float
Minimum value of this field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NumericIndexingSpec
constructor
A new instance of NumericIndexingSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NumericIndexingSpec
Returns a new instance of NumericIndexingSpec.
4387 4388 4389 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_value ⇒ Float
Maximum value of this field. This is meant to be indicative rather than
enforced. Values outside this range will still be indexed, but search may not
be as performant.
Corresponds to the JSON property maxValue
4378 4379 4380 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4378 def max_value @max_value end |
#min_value ⇒ Float
Minimum value of this field. This is meant to be indicative rather than
enforced. Values outside this range will still be indexed, but search may not
be as performant.
Corresponds to the JSON property minValue
4385 4386 4387 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4385 def min_value @min_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4392 4393 4394 4395 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4392 def update!(**args) @max_value = args[:max_value] if args.key?(:max_value) @min_value = args[:min_value] if args.key?(:min_value) end |