Class: Google::Apis::AdminDirectoryV1::User
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::User
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
The Directory API allows you to create and manage your account's users, user aliases, and user Google profile photos. For more information about common tasks, see the User Accounts Developer's Guide and the User Aliases Developer's Guide.
Instance Attribute Summary collapse
-
#addresses ⇒ Object
The list of the user's addresses.
-
#agreed_to_terms ⇒ Boolean
(also: #agreed_to_terms?)
Output only.
-
#aliases ⇒ Array<String>
Output only.
-
#archived ⇒ Boolean
(also: #archived?)
Indicates if user is archived.
-
#change_password_at_next_login ⇒ Boolean
(also: #change_password_at_next_login?)
Indicates if the user is forced to change their password at next login.
-
#creation_time ⇒ DateTime
User's G Suite account creation time.
-
#custom_schemas ⇒ Hash<String,Hash<String,Object>>
Custom fields of the user.
-
#customer_id ⇒ String
Output only.
-
#deletion_time ⇒ DateTime
Corresponds to the JSON property
deletionTime. -
#emails ⇒ Object
The list of the user's email addresses.
-
#etag ⇒ String
Output only.
-
#external_ids ⇒ Object
The list of external IDs for the user, such as an employee or network ID.
-
#gender ⇒ Object
The user's gender.
-
#guest_account_info ⇒ Google::Apis::AdminDirectoryV1::GuestAccountInfo
Account info specific to Guest users.
-
#hash_function ⇒ String
Stores the hash format of the
passwordproperty. -
#id ⇒ String
The unique ID for the user.
-
#ims ⇒ Object
The list of the user's Instant Messenger (IM) accounts.
-
#include_in_global_address_list ⇒ Boolean
(also: #include_in_global_address_list?)
Indicates if the user's profile is visible in the Google Workspace global address list when the contact sharing feature is enabled for the domain.
-
#ip_whitelisted ⇒ Boolean
(also: #ip_whitelisted?)
If
true, the user's IP address is subject to a deprecated IP addressallowlistconfiguration. -
#is_admin ⇒ Boolean
(also: #is_admin?)
Output only.
-
#is_delegated_admin ⇒ Boolean
(also: #is_delegated_admin?)
Output only.
-
#is_enforced_in2_sv ⇒ Boolean
(also: #is_enforced_in2_sv?)
Output only.
-
#is_enrolled_in2_sv ⇒ Boolean
(also: #is_enrolled_in2_sv?)
Output only.
-
#is_guest_user ⇒ Boolean
(also: #is_guest_user?)
Immutable.
-
#is_mailbox_setup ⇒ Boolean
(also: #is_mailbox_setup?)
Output only.
-
#keywords ⇒ Object
The list of the user's keywords.
-
#kind ⇒ String
Output only.
-
#languages ⇒ Object
The user's languages.
-
#last_login_time ⇒ DateTime
User's last login time.
-
#locations ⇒ Object
The user's locations.
-
#name ⇒ Google::Apis::AdminDirectoryV1::UserName
Holds the given and family names of the user, and the read-only
fullNamevalue. -
#non_editable_aliases ⇒ Array<String>
Output only.
-
#notes ⇒ Object
Notes for the user.
-
#org_unit_path ⇒ String
The full path of the parent organization associated with the user.
-
#organizations ⇒ Object
The list of organizations the user belongs to.
-
#password ⇒ String
User's password Corresponds to the JSON property
password. -
#phones ⇒ Object
The list of the user's phone numbers.
-
#posix_accounts ⇒ Object
The list of POSIX account information for the user.
-
#primary_email ⇒ String
The user's primary email address.
-
#recovery_email ⇒ String
Recovery email of the user.
-
#recovery_phone ⇒ String
Recovery phone of the user.
-
#relations ⇒ Object
The list of the user's relationships to other users.
-
#ssh_public_keys ⇒ Object
A list of SSH public keys.
-
#suspended ⇒ Boolean
(also: #suspended?)
Indicates if user is suspended.
-
#suspension_reason ⇒ String
Output only.
-
#thumbnail_photo_etag ⇒ String
Output only.
-
#thumbnail_photo_url ⇒ String
Output only.
-
#websites ⇒ Object
The user's websites.
Instance Method Summary collapse
-
#initialize(**args) ⇒ User
constructor
A new instance of User.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ User
Returns a new instance of User.
4888 4889 4890 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#addresses ⇒ Object
The list of the user's addresses. The maximum allowed data size for this field
is 10KB.
Corresponds to the JSON property addresses
4580 4581 4582 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4580 def addresses @addresses end |
#agreed_to_terms ⇒ Boolean Also known as: agreed_to_terms?
Output only. This property is true if the user has completed an initial
login and accepted the Terms of Service agreement.
Corresponds to the JSON property agreedToTerms
4586 4587 4588 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4586 def agreed_to_terms @agreed_to_terms end |
#aliases ⇒ Array<String>
Output only. The list of the user's alias email addresses.
Corresponds to the JSON property aliases
4592 4593 4594 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4592 def aliases @aliases end |
#archived ⇒ Boolean Also known as: archived?
Indicates if user is archived.
Corresponds to the JSON property archived
4597 4598 4599 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4597 def archived @archived end |
#change_password_at_next_login ⇒ Boolean Also known as: change_password_at_next_login?
Indicates if the user is forced to change their password at next login. This
setting doesn't apply when the user signs in via a third-party identity
provider.
Corresponds to the JSON property changePasswordAtNextLogin
4605 4606 4607 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4605 def change_password_at_next_login @change_password_at_next_login end |
#creation_time ⇒ DateTime
User's G Suite account creation time. (Read-only)
Corresponds to the JSON property creationTime
4611 4612 4613 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4611 def creation_time @creation_time end |
#custom_schemas ⇒ Hash<String,Hash<String,Object>>
Custom fields of the user. The key is a schema_name and its values are '
field_name': 'field_value'.
Corresponds to the JSON property customSchemas
4617 4618 4619 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4617 def custom_schemas @custom_schemas end |
#customer_id ⇒ String
Output only. The customer ID to retrieve all account users. You can use the alias my_customer to represent your account'
s customerId. As a reseller administrator, you can use the resold customer
account's customerId. To get a customerId, use the account's primary
domain in the domain parameter of a users.list request.
Corresponds to the JSON property customerId
4628 4629 4630 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4628 def customer_id @customer_id end |
#deletion_time ⇒ DateTime
Corresponds to the JSON property deletionTime
4633 4634 4635 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4633 def deletion_time @deletion_time end |
#emails ⇒ Object
The list of the user's email addresses. The maximum allowed data size for this
field is 10KB. This excludes publicKeyEncryptionCertificates.
Corresponds to the JSON property emails
4639 4640 4641 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4639 def emails @emails end |
#etag ⇒ String
Output only. ETag of the resource.
Corresponds to the JSON property etag
4644 4645 4646 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4644 def etag @etag end |
#external_ids ⇒ Object
The list of external IDs for the user, such as an employee or network ID. The
maximum allowed data size for this field is 2KB.
Corresponds to the JSON property externalIds
4650 4651 4652 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4650 def external_ids @external_ids end |
#gender ⇒ Object
The user's gender. The maximum allowed data size for this field is 1KB.
Corresponds to the JSON property gender
4655 4656 4657 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4655 def gender @gender end |
#guest_account_info ⇒ Google::Apis::AdminDirectoryV1::GuestAccountInfo
Account info specific to Guest users.
Corresponds to the JSON property guestAccountInfo
4660 4661 4662 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4660 def guest_account_info @guest_account_info end |
#hash_function ⇒ String
Stores the hash format of the password property. The following hashFunction
values are allowed: * MD5 - Accepts simple hex-encoded values. * SHA-1 -
Accepts simple hex-encoded values. * crypt - Compliant with the C crypt
library. Supports the DES, MD5 (
hash prefix $1$), SHA-256 (hash prefix $5$), and SHA-512 (hash prefix $6$
) hash algorithms. If rounds are specified as part of the prefix, they must be
10,000 or fewer.
Corresponds to the JSON property hashFunction
4671 4672 4673 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4671 def hash_function @hash_function end |
#id ⇒ String
The unique ID for the user. A user id can be used as a user request URI's
userKey.
Corresponds to the JSON property id
4677 4678 4679 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4677 def id @id end |
#ims ⇒ Object
The list of the user's Instant Messenger (IM) accounts. A user account can
have multiple ims properties. But, only one of these ims properties can be the
primary IM contact. The maximum allowed data size for this field is 2KB.
Corresponds to the JSON property ims
4684 4685 4686 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4684 def ims @ims end |
#include_in_global_address_list ⇒ Boolean Also known as: include_in_global_address_list?
Indicates if the user's profile is visible in the Google Workspace global
address list when the contact sharing feature is enabled for the domain. For
more information about excluding user profiles, see the administration help
center.
Corresponds to the JSON property includeInGlobalAddressList
4692 4693 4694 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4692 def include_in_global_address_list @include_in_global_address_list end |
#ip_whitelisted ⇒ Boolean Also known as: ip_whitelisted?
If true, the user's IP address is subject to a deprecated IP address
allowlist configuration.
Corresponds to the JSON property ipWhitelisted
4699 4700 4701 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4699 def ip_whitelisted @ip_whitelisted end |
#is_admin ⇒ Boolean Also known as: is_admin?
Output only. Indicates a user with super administrator privileges. The
isAdmin property can only be edited in the Make a user an administrator operation ( makeAdmin method). If
edited in the user insert or update methods,
the edit is ignored by the API service.
Corresponds to the JSON property isAdmin
4713 4714 4715 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4713 def is_admin @is_admin end |
#is_delegated_admin ⇒ Boolean Also known as: is_delegated_admin?
Output only. Indicates if the user is a delegated administrator. Delegated
administrators are supported by the API but cannot create or undelete users,
or make users administrators. These requests are ignored by the API service.
Roles and privileges for administrators are assigned using the Admin console.
Corresponds to the JSON property isDelegatedAdmin
4723 4724 4725 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4723 def is_delegated_admin @is_delegated_admin end |
#is_enforced_in2_sv ⇒ Boolean Also known as: is_enforced_in2_sv?
Output only. Is 2-step verification enforced (Read-only)
Corresponds to the JSON property isEnforcedIn2Sv
4729 4730 4731 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4729 def is_enforced_in2_sv @is_enforced_in2_sv end |
#is_enrolled_in2_sv ⇒ Boolean Also known as: is_enrolled_in2_sv?
Output only. Is enrolled in 2-step verification (Read-only)
Corresponds to the JSON property isEnrolledIn2Sv
4735 4736 4737 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4735 def is_enrolled_in2_sv @is_enrolled_in2_sv end |
#is_guest_user ⇒ Boolean Also known as: is_guest_user?
Immutable. Indicates if the inserted user is a guest.
Corresponds to the JSON property isGuestUser
4741 4742 4743 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4741 def is_guest_user @is_guest_user end |
#is_mailbox_setup ⇒ Boolean Also known as: is_mailbox_setup?
Output only. Indicates if the user's Google mailbox is created. This property
is only applicable if the user has been assigned a Gmail license.
Corresponds to the JSON property isMailboxSetup
4748 4749 4750 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4748 def is_mailbox_setup @is_mailbox_setup end |
#keywords ⇒ Object
The list of the user's keywords. The maximum allowed data size for this field
is 1KB.
Corresponds to the JSON property keywords
4755 4756 4757 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4755 def keywords @keywords end |
#kind ⇒ String
Output only. The type of the API resource. For Users resources, the value is
admin#directory#user.
Corresponds to the JSON property kind
4761 4762 4763 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4761 def kind @kind end |
#languages ⇒ Object
The user's languages. The maximum allowed data size for this field is 1KB.
Corresponds to the JSON property languages
4766 4767 4768 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4766 def languages @languages end |
#last_login_time ⇒ DateTime
User's last login time. (Read-only)
Corresponds to the JSON property lastLoginTime
4771 4772 4773 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4771 def last_login_time @last_login_time end |
#locations ⇒ Object
The user's locations. The maximum allowed data size for this field is 10KB.
Corresponds to the JSON property locations
4776 4777 4778 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4776 def locations @locations end |
#name ⇒ Google::Apis::AdminDirectoryV1::UserName
Holds the given and family names of the user, and the read-only fullName
value. The maximum number of characters in the givenName and in the
familyName values is 60. In addition, name values support unicode/UTF-8
characters, and can contain spaces, letters (a-z), numbers (0-9), dashes (-),
forward slashes (/), and periods (.). For more information about character
usage rules, see the administration help center. Maximum allowed data size for this field is 1KB.
Corresponds to the JSON property name
4787 4788 4789 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4787 def name @name end |
#non_editable_aliases ⇒ Array<String>
Output only. The list of the user's non-editable alias email addresses. These
are typically outside the account's primary domain or sub-domain.
Corresponds to the JSON property nonEditableAliases
4793 4794 4795 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4793 def non_editable_aliases @non_editable_aliases end |
#notes ⇒ Object
Notes for the user.
Corresponds to the JSON property notes
4798 4799 4800 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4798 def notes @notes end |
#org_unit_path ⇒ String
The full path of the parent organization associated with the user. If the
parent organization is the top-level, it is represented as a forward slash (/
).
Corresponds to the JSON property orgUnitPath
4805 4806 4807 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4805 def org_unit_path @org_unit_path end |
#organizations ⇒ Object
The list of organizations the user belongs to. The maximum allowed data size
for this field is 10KB.
Corresponds to the JSON property organizations
4811 4812 4813 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4811 def organizations @organizations end |
#password ⇒ String
User's password
Corresponds to the JSON property password
4816 4817 4818 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4816 def password @password end |
#phones ⇒ Object
The list of the user's phone numbers. The maximum allowed data size for this
field is 1KB.
Corresponds to the JSON property phones
4822 4823 4824 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4822 def phones @phones end |
#posix_accounts ⇒ Object
The list of POSIX
account information for the user.
Corresponds to the JSON property posixAccounts
4828 4829 4830 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4828 def posix_accounts @posix_accounts end |
#primary_email ⇒ String
The user's primary email address. This property is required in a request to
create a user account. The primaryEmail must be unique and cannot be an
alias of another user.
Corresponds to the JSON property primaryEmail
4835 4836 4837 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4835 def primary_email @primary_email end |
#recovery_email ⇒ String
Recovery email of the user.
Corresponds to the JSON property recoveryEmail
4840 4841 4842 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4840 def recovery_email @recovery_email end |
#recovery_phone ⇒ String
Recovery phone of the user. The phone number must be in the E.164 format,
starting with the plus sign (+). Example: +16506661212.
Corresponds to the JSON property recoveryPhone
4846 4847 4848 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4846 def recovery_phone @recovery_phone end |
#relations ⇒ Object
The list of the user's relationships to other users. The maximum allowed data
size for this field is 2KB.
Corresponds to the JSON property relations
4852 4853 4854 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4852 def relations @relations end |
#ssh_public_keys ⇒ Object
A list of SSH public keys.
Corresponds to the JSON property sshPublicKeys
4857 4858 4859 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4857 def ssh_public_keys @ssh_public_keys end |
#suspended ⇒ Boolean Also known as: suspended?
Indicates if user is suspended.
Corresponds to the JSON property suspended
4862 4863 4864 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4862 def suspended @suspended end |
#suspension_reason ⇒ String
Output only. Has the reason a user account is suspended either by the
administrator or by Google at the time of suspension. The property is returned
only if the suspended property is true.
Corresponds to the JSON property suspensionReason
4870 4871 4872 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4870 def suspension_reason @suspension_reason end |
#thumbnail_photo_etag ⇒ String
Output only. ETag of the user's photo (Read-only)
Corresponds to the JSON property thumbnailPhotoEtag
4875 4876 4877 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4875 def thumbnail_photo_etag @thumbnail_photo_etag end |
#thumbnail_photo_url ⇒ String
Output only. The URL of the user's profile photo. The URL might be temporary
or private.
Corresponds to the JSON property thumbnailPhotoUrl
4881 4882 4883 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4881 def thumbnail_photo_url @thumbnail_photo_url end |
#websites ⇒ Object
The user's websites. The maximum allowed data size for this field is 2KB.
Corresponds to the JSON property websites
4886 4887 4888 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4886 def websites @websites end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4893 4894 4895 4896 4897 4898 4899 4900 4901 4902 4903 4904 4905 4906 4907 4908 4909 4910 4911 4912 4913 4914 4915 4916 4917 4918 4919 4920 4921 4922 4923 4924 4925 4926 4927 4928 4929 4930 4931 4932 4933 4934 4935 4936 4937 4938 4939 4940 4941 4942 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4893 def update!(**args) @addresses = args[:addresses] if args.key?(:addresses) @agreed_to_terms = args[:agreed_to_terms] if args.key?(:agreed_to_terms) @aliases = args[:aliases] if args.key?(:aliases) @archived = args[:archived] if args.key?(:archived) @change_password_at_next_login = args[:change_password_at_next_login] if args.key?(:change_password_at_next_login) @creation_time = args[:creation_time] if args.key?(:creation_time) @custom_schemas = args[:custom_schemas] if args.key?(:custom_schemas) @customer_id = args[:customer_id] if args.key?(:customer_id) @deletion_time = args[:deletion_time] if args.key?(:deletion_time) @emails = args[:emails] if args.key?(:emails) @etag = args[:etag] if args.key?(:etag) @external_ids = args[:external_ids] if args.key?(:external_ids) @gender = args[:gender] if args.key?(:gender) @guest_account_info = args[:guest_account_info] if args.key?(:guest_account_info) @hash_function = args[:hash_function] if args.key?(:hash_function) @id = args[:id] if args.key?(:id) @ims = args[:ims] if args.key?(:ims) @include_in_global_address_list = args[:include_in_global_address_list] if args.key?(:include_in_global_address_list) @ip_whitelisted = args[:ip_whitelisted] if args.key?(:ip_whitelisted) @is_admin = args[:is_admin] if args.key?(:is_admin) @is_delegated_admin = args[:is_delegated_admin] if args.key?(:is_delegated_admin) @is_enforced_in2_sv = args[:is_enforced_in2_sv] if args.key?(:is_enforced_in2_sv) @is_enrolled_in2_sv = args[:is_enrolled_in2_sv] if args.key?(:is_enrolled_in2_sv) @is_guest_user = args[:is_guest_user] if args.key?(:is_guest_user) @is_mailbox_setup = args[:is_mailbox_setup] if args.key?(:is_mailbox_setup) @keywords = args[:keywords] if args.key?(:keywords) @kind = args[:kind] if args.key?(:kind) @languages = args[:languages] if args.key?(:languages) @last_login_time = args[:last_login_time] if args.key?(:last_login_time) @locations = args[:locations] if args.key?(:locations) @name = args[:name] if args.key?(:name) @non_editable_aliases = args[:non_editable_aliases] if args.key?(:non_editable_aliases) @notes = args[:notes] if args.key?(:notes) @org_unit_path = args[:org_unit_path] if args.key?(:org_unit_path) @organizations = args[:organizations] if args.key?(:organizations) @password = args[:password] if args.key?(:password) @phones = args[:phones] if args.key?(:phones) @posix_accounts = args[:posix_accounts] if args.key?(:posix_accounts) @primary_email = args[:primary_email] if args.key?(:primary_email) @recovery_email = args[:recovery_email] if args.key?(:recovery_email) @recovery_phone = args[:recovery_phone] if args.key?(:recovery_phone) @relations = args[:relations] if args.key?(:relations) @ssh_public_keys = args[:ssh_public_keys] if args.key?(:ssh_public_keys) @suspended = args[:suspended] if args.key?(:suspended) @suspension_reason = args[:suspension_reason] if args.key?(:suspension_reason) @thumbnail_photo_etag = args[:thumbnail_photo_etag] if args.key?(:thumbnail_photo_etag) @thumbnail_photo_url = args[:thumbnail_photo_url] if args.key?(:thumbnail_photo_url) @websites = args[:websites] if args.key?(:websites) end |