Class: Google::Apis::AdminDirectoryV1::UserAbout
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserAbout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
JSON template for About (notes) of a user in Directory API.
Instance Attribute Summary collapse
-
#content_type ⇒ String
About entry can have a type which indicates the content type.
-
#value ⇒ String
Actual value of notes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserAbout
constructor
A new instance of UserAbout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserAbout
Returns a new instance of UserAbout.
4972 4973 4974 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_type ⇒ String
About entry can have a type which indicates the content type. It can either be
plain or html. By default, notes contents are assumed to contain plain text.
Corresponds to the JSON property contentType
4965 4966 4967 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4965 def content_type @content_type end |
#value ⇒ String
Actual value of notes.
Corresponds to the JSON property value
4970 4971 4972 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4970 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4977 4978 4979 4980 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4977 def update!(**args) @content_type = args[:content_type] if args.key?(:content_type) @value = args[:value] if args.key?(:value) end |