Class: Google::Apis::AdminDirectoryV1::UserAddress
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
JSON template for address.
Instance Attribute Summary collapse
-
#country ⇒ String
Country.
-
#country_code ⇒ String
Country code.
-
#custom_type ⇒ String
Custom type.
-
#extended_address ⇒ String
Extended Address.
-
#formatted ⇒ String
Formatted address.
-
#locality ⇒ String
Locality.
-
#po_box ⇒ String
Other parts of address.
-
#postal_code ⇒ String
Postal code.
-
#primary ⇒ Boolean
(also: #primary?)
If this is user's primary address.
-
#region ⇒ String
Region.
-
#source_is_structured ⇒ Boolean
(also: #source_is_structured?)
User supplied address was structured.
-
#street_address ⇒ String
Street.
-
#type ⇒ String
Each entry can have a type which indicates standard values of that entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserAddress
constructor
A new instance of UserAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserAddress
Returns a new instance of UserAddress.
5059 5060 5061 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5059 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
Country.
Corresponds to the JSON property country
4990 4991 4992 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4990 def country @country end |
#country_code ⇒ String
Country code.
Corresponds to the JSON property countryCode
4995 4996 4997 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4995 def country_code @country_code end |
#custom_type ⇒ String
Custom type.
Corresponds to the JSON property customType
5000 5001 5002 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5000 def custom_type @custom_type end |
#extended_address ⇒ String
Extended Address.
Corresponds to the JSON property extendedAddress
5005 5006 5007 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5005 def extended_address @extended_address end |
#formatted ⇒ String
Formatted address.
Corresponds to the JSON property formatted
5010 5011 5012 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5010 def formatted @formatted end |
#locality ⇒ String
Locality.
Corresponds to the JSON property locality
5015 5016 5017 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5015 def locality @locality end |
#po_box ⇒ String
Other parts of address.
Corresponds to the JSON property poBox
5020 5021 5022 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5020 def po_box @po_box end |
#postal_code ⇒ String
Postal code.
Corresponds to the JSON property postalCode
5025 5026 5027 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5025 def postal_code @postal_code end |
#primary ⇒ Boolean Also known as: primary?
If this is user's primary address. Only one entry could be marked as primary.
Corresponds to the JSON property primary
5030 5031 5032 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5030 def primary @primary end |
#region ⇒ String
Region.
Corresponds to the JSON property region
5036 5037 5038 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5036 def region @region end |
#source_is_structured ⇒ Boolean Also known as: source_is_structured?
User supplied address was structured. Structured addresses are NOT supported
at this time. You might be able to write structured addresses but any values
will eventually be clobbered.
Corresponds to the JSON property sourceIsStructured
5043 5044 5045 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5043 def source_is_structured @source_is_structured end |
#street_address ⇒ String
Street.
Corresponds to the JSON property streetAddress
5049 5050 5051 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5049 def street_address @street_address end |
#type ⇒ String
Each entry can have a type which indicates standard values of that entry. For
example address could be of home work etc. In addition to the standard type an
entry can have a custom type and can take any value. Such type should have the
CUSTOM value as type and also have a customType value.
Corresponds to the JSON property type
5057 5058 5059 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5057 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5064 def update!(**args) @country = args[:country] if args.key?(:country) @country_code = args[:country_code] if args.key?(:country_code) @custom_type = args[:custom_type] if args.key?(:custom_type) @extended_address = args[:extended_address] if args.key?(:extended_address) @formatted = args[:formatted] if args.key?(:formatted) @locality = args[:locality] if args.key?(:locality) @po_box = args[:po_box] if args.key?(:po_box) @postal_code = args[:postal_code] if args.key?(:postal_code) @primary = args[:primary] if args.key?(:primary) @region = args[:region] if args.key?(:region) @source_is_structured = args[:source_is_structured] if args.key?(:source_is_structured) @street_address = args[:street_address] if args.key?(:street_address) @type = args[:type] if args.key?(:type) end |