Class: Google::Apis::AdminDirectoryV1::UserAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for address.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserAddress

Returns a new instance of UserAddress.



5047
5048
5049
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

Country. Corresponds to the JSON property country

Returns:

  • (String)


4978
4979
4980
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4978

def country
  @country
end

#country_codeString

Country code. Corresponds to the JSON property countryCode

Returns:

  • (String)


4983
4984
4985
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4983

def country_code
  @country_code
end

#custom_typeString

Custom type. Corresponds to the JSON property customType

Returns:

  • (String)


4988
4989
4990
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4988

def custom_type
  @custom_type
end

#extended_addressString

Extended Address. Corresponds to the JSON property extendedAddress

Returns:

  • (String)


4993
4994
4995
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4993

def extended_address
  @extended_address
end

#formattedString

Formatted address. Corresponds to the JSON property formatted

Returns:

  • (String)


4998
4999
5000
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4998

def formatted
  @formatted
end

#localityString

Locality. Corresponds to the JSON property locality

Returns:

  • (String)


5003
5004
5005
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5003

def locality
  @locality
end

#po_boxString

Other parts of address. Corresponds to the JSON property poBox

Returns:

  • (String)


5008
5009
5010
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5008

def po_box
  @po_box
end

#postal_codeString

Postal code. Corresponds to the JSON property postalCode

Returns:

  • (String)


5013
5014
5015
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5013

def postal_code
  @postal_code
end

#primaryBoolean Also known as: primary?

If this is user's primary address. Only one entry could be marked as primary. Corresponds to the JSON property primary

Returns:

  • (Boolean)


5018
5019
5020
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5018

def primary
  @primary
end

#regionString

Region. Corresponds to the JSON property region

Returns:

  • (String)


5024
5025
5026
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5024

def region
  @region
end

#source_is_structuredBoolean Also known as: source_is_structured?

User supplied address was structured. Structured addresses are NOT supported at this time. You might be able to write structured addresses but any values will eventually be clobbered. Corresponds to the JSON property sourceIsStructured

Returns:

  • (Boolean)


5031
5032
5033
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5031

def source_is_structured
  @source_is_structured
end

#street_addressString

Street. Corresponds to the JSON property streetAddress

Returns:

  • (String)


5037
5038
5039
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5037

def street_address
  @street_address
end

#typeString

Each entry can have a type which indicates standard values of that entry. For example address could be of home work etc. In addition to the standard type an entry can have a custom type and can take any value. Such type should have the CUSTOM value as type and also have a customType value. Corresponds to the JSON property type

Returns:

  • (String)


5045
5046
5047
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5045

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5052
5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
5065
5066
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5052

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @country_code = args[:country_code] if args.key?(:country_code)
  @custom_type = args[:custom_type] if args.key?(:custom_type)
  @extended_address = args[:extended_address] if args.key?(:extended_address)
  @formatted = args[:formatted] if args.key?(:formatted)
  @locality = args[:locality] if args.key?(:locality)
  @po_box = args[:po_box] if args.key?(:po_box)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @primary = args[:primary] if args.key?(:primary)
  @region = args[:region] if args.key?(:region)
  @source_is_structured = args[:source_is_structured] if args.key?(:source_is_structured)
  @street_address = args[:street_address] if args.key?(:street_address)
  @type = args[:type] if args.key?(:type)
end