Class: Google::Apis::AdminDirectoryV1::UserAddress
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserAddress
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
JSON template for address.
Instance Attribute Summary collapse
-
#country ⇒ String
Country.
-
#country_code ⇒ String
Country code.
-
#custom_type ⇒ String
Custom type.
-
#extended_address ⇒ String
Extended Address.
-
#formatted ⇒ String
Formatted address.
-
#locality ⇒ String
Locality.
-
#po_box ⇒ String
Other parts of address.
-
#postal_code ⇒ String
Postal code.
-
#primary ⇒ Boolean
(also: #primary?)
If this is user's primary address.
-
#region ⇒ String
Region.
-
#source_is_structured ⇒ Boolean
(also: #source_is_structured?)
User supplied address was structured.
-
#street_address ⇒ String
Street.
-
#type ⇒ String
Each entry can have a type which indicates standard values of that entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserAddress
constructor
A new instance of UserAddress.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserAddress
Returns a new instance of UserAddress.
5047 5048 5049 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#country ⇒ String
Country.
Corresponds to the JSON property country
4978 4979 4980 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4978 def country @country end |
#country_code ⇒ String
Country code.
Corresponds to the JSON property countryCode
4983 4984 4985 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4983 def country_code @country_code end |
#custom_type ⇒ String
Custom type.
Corresponds to the JSON property customType
4988 4989 4990 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4988 def custom_type @custom_type end |
#extended_address ⇒ String
Extended Address.
Corresponds to the JSON property extendedAddress
4993 4994 4995 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4993 def extended_address @extended_address end |
#formatted ⇒ String
Formatted address.
Corresponds to the JSON property formatted
4998 4999 5000 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4998 def formatted @formatted end |
#locality ⇒ String
Locality.
Corresponds to the JSON property locality
5003 5004 5005 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5003 def locality @locality end |
#po_box ⇒ String
Other parts of address.
Corresponds to the JSON property poBox
5008 5009 5010 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5008 def po_box @po_box end |
#postal_code ⇒ String
Postal code.
Corresponds to the JSON property postalCode
5013 5014 5015 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5013 def postal_code @postal_code end |
#primary ⇒ Boolean Also known as: primary?
If this is user's primary address. Only one entry could be marked as primary.
Corresponds to the JSON property primary
5018 5019 5020 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5018 def primary @primary end |
#region ⇒ String
Region.
Corresponds to the JSON property region
5024 5025 5026 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5024 def region @region end |
#source_is_structured ⇒ Boolean Also known as: source_is_structured?
User supplied address was structured. Structured addresses are NOT supported
at this time. You might be able to write structured addresses but any values
will eventually be clobbered.
Corresponds to the JSON property sourceIsStructured
5031 5032 5033 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5031 def source_is_structured @source_is_structured end |
#street_address ⇒ String
Street.
Corresponds to the JSON property streetAddress
5037 5038 5039 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5037 def street_address @street_address end |
#type ⇒ String
Each entry can have a type which indicates standard values of that entry. For
example address could be of home work etc. In addition to the standard type an
entry can have a custom type and can take any value. Such type should have the
CUSTOM value as type and also have a customType value.
Corresponds to the JSON property type
5045 5046 5047 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5045 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5052 5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5052 def update!(**args) @country = args[:country] if args.key?(:country) @country_code = args[:country_code] if args.key?(:country_code) @custom_type = args[:custom_type] if args.key?(:custom_type) @extended_address = args[:extended_address] if args.key?(:extended_address) @formatted = args[:formatted] if args.key?(:formatted) @locality = args[:locality] if args.key?(:locality) @po_box = args[:po_box] if args.key?(:po_box) @postal_code = args[:postal_code] if args.key?(:postal_code) @primary = args[:primary] if args.key?(:primary) @region = args[:region] if args.key?(:region) @source_is_structured = args[:source_is_structured] if args.key?(:source_is_structured) @street_address = args[:street_address] if args.key?(:street_address) @type = args[:type] if args.key?(:type) end |