Class: Google::Apis::AdminDirectoryV1::UserAddress

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for address.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserAddress

Returns a new instance of UserAddress.



5045
5046
5047
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5045

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countryString

Country. Corresponds to the JSON property country

Returns:

  • (String)


4976
4977
4978
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4976

def country
  @country
end

#country_codeString

Country code. Corresponds to the JSON property countryCode

Returns:

  • (String)


4981
4982
4983
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4981

def country_code
  @country_code
end

#custom_typeString

Custom type. Corresponds to the JSON property customType

Returns:

  • (String)


4986
4987
4988
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4986

def custom_type
  @custom_type
end

#extended_addressString

Extended Address. Corresponds to the JSON property extendedAddress

Returns:

  • (String)


4991
4992
4993
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4991

def extended_address
  @extended_address
end

#formattedString

Formatted address. Corresponds to the JSON property formatted

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 4996

def formatted
  @formatted
end

#localityString

Locality. Corresponds to the JSON property locality

Returns:

  • (String)


5001
5002
5003
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5001

def locality
  @locality
end

#po_boxString

Other parts of address. Corresponds to the JSON property poBox

Returns:

  • (String)


5006
5007
5008
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5006

def po_box
  @po_box
end

#postal_codeString

Postal code. Corresponds to the JSON property postalCode

Returns:

  • (String)


5011
5012
5013
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5011

def postal_code
  @postal_code
end

#primaryBoolean Also known as: primary?

If this is user's primary address. Only one entry could be marked as primary. Corresponds to the JSON property primary

Returns:

  • (Boolean)


5016
5017
5018
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5016

def primary
  @primary
end

#regionString

Region. Corresponds to the JSON property region

Returns:

  • (String)


5022
5023
5024
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5022

def region
  @region
end

#source_is_structuredBoolean Also known as: source_is_structured?

User supplied address was structured. Structured addresses are NOT supported at this time. You might be able to write structured addresses but any values will eventually be clobbered. Corresponds to the JSON property sourceIsStructured

Returns:

  • (Boolean)


5029
5030
5031
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5029

def source_is_structured
  @source_is_structured
end

#street_addressString

Street. Corresponds to the JSON property streetAddress

Returns:

  • (String)


5035
5036
5037
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5035

def street_address
  @street_address
end

#typeString

Each entry can have a type which indicates standard values of that entry. For example address could be of home work etc. In addition to the standard type an entry can have a custom type and can take any value. Such type should have the CUSTOM value as type and also have a customType value. Corresponds to the JSON property type

Returns:

  • (String)


5043
5044
5045
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5043

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5050
5051
5052
5053
5054
5055
5056
5057
5058
5059
5060
5061
5062
5063
5064
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5050

def update!(**args)
  @country = args[:country] if args.key?(:country)
  @country_code = args[:country_code] if args.key?(:country_code)
  @custom_type = args[:custom_type] if args.key?(:custom_type)
  @extended_address = args[:extended_address] if args.key?(:extended_address)
  @formatted = args[:formatted] if args.key?(:formatted)
  @locality = args[:locality] if args.key?(:locality)
  @po_box = args[:po_box] if args.key?(:po_box)
  @postal_code = args[:postal_code] if args.key?(:postal_code)
  @primary = args[:primary] if args.key?(:primary)
  @region = args[:region] if args.key?(:region)
  @source_is_structured = args[:source_is_structured] if args.key?(:source_is_structured)
  @street_address = args[:street_address] if args.key?(:street_address)
  @type = args[:type] if args.key?(:type)
end