Class: Google::Apis::AdminDirectoryV1::UserLanguage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for a language entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserLanguage

Returns a new instance of UserLanguage.



5375
5376
5377
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_languageString

Other language. User can provide their own language name if there is no corresponding ISO 639 language code. If this is set, languageCode can't be set. Corresponds to the JSON property customLanguage

Returns:

  • (String)


5357
5358
5359
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5357

def custom_language
  @custom_language
end

#language_codeString

ISO 639 string representation of a language. See Language Codes for the list of supported codes. Valid language codes outside the supported set will be accepted by the API but may lead to unexpected behavior. Illegal values cause SchemaException. If this is set, customLanguage can't be set. Corresponds to the JSON property languageCode

Returns:

  • (String)


5366
5367
5368
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5366

def language_code
  @language_code
end

#preferenceString

Optional. If present, controls whether the specified languageCode is the user's preferred language. If customLanguage is set, this can't be set. Allowed values are preferred and not_preferred. Corresponds to the JSON property preference

Returns:

  • (String)


5373
5374
5375
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5373

def preference
  @preference
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5380
5381
5382
5383
5384
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5380

def update!(**args)
  @custom_language = args[:custom_language] if args.key?(:custom_language)
  @language_code = args[:language_code] if args.key?(:language_code)
  @preference = args[:preference] if args.key?(:preference)
end