Class: Google::Apis::AdminDirectoryV1::UserLanguage
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserLanguage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
JSON template for a language entry.
Instance Attribute Summary collapse
-
#custom_language ⇒ String
Other language.
-
#language_code ⇒ String
ISO 639 string representation of a language.
-
#preference ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserLanguage
constructor
A new instance of UserLanguage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserLanguage
Returns a new instance of UserLanguage.
5373 5374 5375 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_language ⇒ String
Other language. User can provide their own language name if there is no
corresponding ISO 639 language code. If this is set, languageCode can't be
set.
Corresponds to the JSON property customLanguage
5355 5356 5357 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5355 def custom_language @custom_language end |
#language_code ⇒ String
ISO 639 string representation of a language. See Language Codes for the list of supported codes. Valid language codes
outside the supported set will be accepted by the API but may lead to
unexpected behavior. Illegal values cause SchemaException. If this is set,
customLanguage can't be set.
Corresponds to the JSON property languageCode
5364 5365 5366 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5364 def language_code @language_code end |
#preference ⇒ String
Optional. If present, controls whether the specified languageCode is the
user's preferred language. If customLanguage is set, this can't be set.
Allowed values are preferred and not_preferred.
Corresponds to the JSON property preference
5371 5372 5373 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5371 def preference @preference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5378 5379 5380 5381 5382 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5378 def update!(**args) @custom_language = args[:custom_language] if args.key?(:custom_language) @language_code = args[:language_code] if args.key?(:language_code) @preference = args[:preference] if args.key?(:preference) end |