Class: Google::Apis::AdminDirectoryV1::UserOrganization
- Inherits:
-
Object
- Object
- Google::Apis::AdminDirectoryV1::UserOrganization
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb
Overview
JSON template for an organization entry.
Instance Attribute Summary collapse
-
#cost_center ⇒ String
The cost center of the users department.
-
#custom_type ⇒ String
Custom type.
-
#department ⇒ String
Department within the organization.
-
#description ⇒ String
Description of the organization.
-
#domain ⇒ String
The domain to which the organization belongs to.
-
#full_time_equivalent ⇒ Fixnum
The full-time equivalent millipercent within the organization (100000 = 100%).
-
#location ⇒ String
Location of the organization.
-
#name ⇒ String
Name of the organization Corresponds to the JSON property
name. -
#primary ⇒ Boolean
(also: #primary?)
If it user's primary organization.
-
#symbol ⇒ String
Symbol of the organization.
-
#title ⇒ String
Title (designation) of the user in the organization.
-
#type ⇒ String
Each entry can have a type which indicates standard types of that entry.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UserOrganization
constructor
A new instance of UserOrganization.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UserOrganization
Returns a new instance of UserOrganization.
5620 5621 5622 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5620 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cost_center ⇒ String
The cost center of the users department.
Corresponds to the JSON property costCenter
5559 5560 5561 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5559 def cost_center @cost_center end |
#custom_type ⇒ String
Custom type.
Corresponds to the JSON property customType
5564 5565 5566 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5564 def custom_type @custom_type end |
#department ⇒ String
Department within the organization.
Corresponds to the JSON property department
5569 5570 5571 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5569 def department @department end |
#description ⇒ String
Description of the organization.
Corresponds to the JSON property description
5574 5575 5576 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5574 def description @description end |
#domain ⇒ String
The domain to which the organization belongs to.
Corresponds to the JSON property domain
5579 5580 5581 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5579 def domain @domain end |
#full_time_equivalent ⇒ Fixnum
The full-time equivalent millipercent within the organization (100000 = 100%).
Corresponds to the JSON property fullTimeEquivalent
5584 5585 5586 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5584 def full_time_equivalent @full_time_equivalent end |
#location ⇒ String
Location of the organization. This need not be fully qualified address.
Corresponds to the JSON property location
5589 5590 5591 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5589 def location @location end |
#name ⇒ String
Name of the organization
Corresponds to the JSON property name
5594 5595 5596 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5594 def name @name end |
#primary ⇒ Boolean Also known as: primary?
If it user's primary organization.
Corresponds to the JSON property primary
5599 5600 5601 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5599 def primary @primary end |
#symbol ⇒ String
Symbol of the organization.
Corresponds to the JSON property symbol
5605 5606 5607 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5605 def symbol @symbol end |
#title ⇒ String
Title (designation) of the user in the organization.
Corresponds to the JSON property title
5610 5611 5612 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5610 def title @title end |
#type ⇒ String
Each entry can have a type which indicates standard types of that entry. For
example organization could be of school work etc. In addition to the standard
type an entry can have a custom type and can give it any name. Such types
should have the CUSTOM value as type and also have a CustomType value.
Corresponds to the JSON property type
5618 5619 5620 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5618 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5625 5626 5627 5628 5629 5630 5631 5632 5633 5634 5635 5636 5637 5638 |
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5625 def update!(**args) @cost_center = args[:cost_center] if args.key?(:cost_center) @custom_type = args[:custom_type] if args.key?(:custom_type) @department = args[:department] if args.key?(:department) @description = args[:description] if args.key?(:description) @domain = args[:domain] if args.key?(:domain) @full_time_equivalent = args[:full_time_equivalent] if args.key?(:full_time_equivalent) @location = args[:location] if args.key?(:location) @name = args[:name] if args.key?(:name) @primary = args[:primary] if args.key?(:primary) @symbol = args[:symbol] if args.key?(:symbol) @title = args[:title] if args.key?(:title) @type = args[:type] if args.key?(:type) end |