Class: Google::Apis::AdminDirectoryV1::UserPosixAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for a POSIX account entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserPosixAccount

Returns a new instance of UserPosixAccount.



5774
5775
5776
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

A POSIX account field identifier. Corresponds to the JSON property accountId

Returns:

  • (String)


5726
5727
5728
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5726

def 
  @account_id
end

#gecosString

The GECOS (user information) for this account. Corresponds to the JSON property gecos

Returns:

  • (String)


5731
5732
5733
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5731

def gecos
  @gecos
end

#gidFixnum

The default group ID. Corresponds to the JSON property gid

Returns:

  • (Fixnum)


5736
5737
5738
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5736

def gid
  @gid
end

#home_directoryString

The path to the home directory for this account. Corresponds to the JSON property homeDirectory

Returns:

  • (String)


5741
5742
5743
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5741

def home_directory
  @home_directory
end

#operating_system_typeString

The operating system type for this account. Corresponds to the JSON property operatingSystemType

Returns:

  • (String)


5746
5747
5748
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5746

def operating_system_type
  @operating_system_type
end

#primaryBoolean Also known as: primary?

If this is user's primary account within the SystemId. Corresponds to the JSON property primary

Returns:

  • (Boolean)


5751
5752
5753
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5751

def primary
  @primary
end

#shellString

The path to the login shell for this account. Corresponds to the JSON property shell

Returns:

  • (String)


5757
5758
5759
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5757

def shell
  @shell
end

#system_idString

System identifier for which account Username or Uid apply to. Corresponds to the JSON property systemId

Returns:

  • (String)


5762
5763
5764
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5762

def system_id
  @system_id
end

#uidFixnum

The POSIX compliant user ID. Corresponds to the JSON property uid

Returns:

  • (Fixnum)


5767
5768
5769
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5767

def uid
  @uid
end

#usernameString

The username of the account. Corresponds to the JSON property username

Returns:

  • (String)


5772
5773
5774
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5772

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5779
5780
5781
5782
5783
5784
5785
5786
5787
5788
5789
5790
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5779

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @gecos = args[:gecos] if args.key?(:gecos)
  @gid = args[:gid] if args.key?(:gid)
  @home_directory = args[:home_directory] if args.key?(:home_directory)
  @operating_system_type = args[:operating_system_type] if args.key?(:operating_system_type)
  @primary = args[:primary] if args.key?(:primary)
  @shell = args[:shell] if args.key?(:shell)
  @system_id = args[:system_id] if args.key?(:system_id)
  @uid = args[:uid] if args.key?(:uid)
  @username = args[:username] if args.key?(:username)
end