Class: Google::Apis::AdminDirectoryV1::UserPosixAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for a POSIX account entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserPosixAccount

Returns a new instance of UserPosixAccount.



5762
5763
5764
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

A POSIX account field identifier. Corresponds to the JSON property accountId

Returns:

  • (String)


5714
5715
5716
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5714

def 
  @account_id
end

#gecosString

The GECOS (user information) for this account. Corresponds to the JSON property gecos

Returns:

  • (String)


5719
5720
5721
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5719

def gecos
  @gecos
end

#gidFixnum

The default group ID. Corresponds to the JSON property gid

Returns:

  • (Fixnum)


5724
5725
5726
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5724

def gid
  @gid
end

#home_directoryString

The path to the home directory for this account. Corresponds to the JSON property homeDirectory

Returns:

  • (String)


5729
5730
5731
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5729

def home_directory
  @home_directory
end

#operating_system_typeString

The operating system type for this account. Corresponds to the JSON property operatingSystemType

Returns:

  • (String)


5734
5735
5736
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5734

def operating_system_type
  @operating_system_type
end

#primaryBoolean Also known as: primary?

If this is user's primary account within the SystemId. Corresponds to the JSON property primary

Returns:

  • (Boolean)


5739
5740
5741
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5739

def primary
  @primary
end

#shellString

The path to the login shell for this account. Corresponds to the JSON property shell

Returns:

  • (String)


5745
5746
5747
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5745

def shell
  @shell
end

#system_idString

System identifier for which account Username or Uid apply to. Corresponds to the JSON property systemId

Returns:

  • (String)


5750
5751
5752
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5750

def system_id
  @system_id
end

#uidFixnum

The POSIX compliant user ID. Corresponds to the JSON property uid

Returns:

  • (Fixnum)


5755
5756
5757
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5755

def uid
  @uid
end

#usernameString

The username of the account. Corresponds to the JSON property username

Returns:

  • (String)


5760
5761
5762
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5760

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5767
5768
5769
5770
5771
5772
5773
5774
5775
5776
5777
5778
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5767

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @gecos = args[:gecos] if args.key?(:gecos)
  @gid = args[:gid] if args.key?(:gid)
  @home_directory = args[:home_directory] if args.key?(:home_directory)
  @operating_system_type = args[:operating_system_type] if args.key?(:operating_system_type)
  @primary = args[:primary] if args.key?(:primary)
  @shell = args[:shell] if args.key?(:shell)
  @system_id = args[:system_id] if args.key?(:system_id)
  @uid = args[:uid] if args.key?(:uid)
  @username = args[:username] if args.key?(:username)
end