Class: Google::Apis::AdminDirectoryV1::UserPosixAccount

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/admin_directory_v1/classes.rb,
lib/google/apis/admin_directory_v1/representations.rb,
lib/google/apis/admin_directory_v1/representations.rb

Overview

JSON template for a POSIX account entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UserPosixAccount

Returns a new instance of UserPosixAccount.



5760
5761
5762
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

A POSIX account field identifier. Corresponds to the JSON property accountId

Returns:

  • (String)


5712
5713
5714
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5712

def 
  @account_id
end

#gecosString

The GECOS (user information) for this account. Corresponds to the JSON property gecos

Returns:

  • (String)


5717
5718
5719
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5717

def gecos
  @gecos
end

#gidFixnum

The default group ID. Corresponds to the JSON property gid

Returns:

  • (Fixnum)


5722
5723
5724
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5722

def gid
  @gid
end

#home_directoryString

The path to the home directory for this account. Corresponds to the JSON property homeDirectory

Returns:

  • (String)


5727
5728
5729
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5727

def home_directory
  @home_directory
end

#operating_system_typeString

The operating system type for this account. Corresponds to the JSON property operatingSystemType

Returns:

  • (String)


5732
5733
5734
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5732

def operating_system_type
  @operating_system_type
end

#primaryBoolean Also known as: primary?

If this is user's primary account within the SystemId. Corresponds to the JSON property primary

Returns:

  • (Boolean)


5737
5738
5739
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5737

def primary
  @primary
end

#shellString

The path to the login shell for this account. Corresponds to the JSON property shell

Returns:

  • (String)


5743
5744
5745
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5743

def shell
  @shell
end

#system_idString

System identifier for which account Username or Uid apply to. Corresponds to the JSON property systemId

Returns:

  • (String)


5748
5749
5750
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5748

def system_id
  @system_id
end

#uidFixnum

The POSIX compliant user ID. Corresponds to the JSON property uid

Returns:

  • (Fixnum)


5753
5754
5755
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5753

def uid
  @uid
end

#usernameString

The username of the account. Corresponds to the JSON property username

Returns:

  • (String)


5758
5759
5760
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5758

def username
  @username
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5765
5766
5767
5768
5769
5770
5771
5772
5773
5774
5775
5776
# File 'lib/google/apis/admin_directory_v1/classes.rb', line 5765

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @gecos = args[:gecos] if args.key?(:gecos)
  @gid = args[:gid] if args.key?(:gid)
  @home_directory = args[:home_directory] if args.key?(:home_directory)
  @operating_system_type = args[:operating_system_type] if args.key?(:operating_system_type)
  @primary = args[:primary] if args.key?(:primary)
  @shell = args[:shell] if args.key?(:shell)
  @system_id = args[:system_id] if args.key?(:system_id)
  @uid = args[:uid] if args.key?(:uid)
  @username = args[:username] if args.key?(:username)
end